#!/bin/sh
#							  Airly
#					Based on http://map.airly.org
#							 1.0-r46
#
#    Copyright (C) 2021  Ampersand
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see https://www.gnu.org/licenses/.
#
NOW=$(date +'[%Y-%m-%d %H:%M:%S]')
API=`head -n 1 /etc/enigma2/Airly/api.txt | tr -d "\015"`
APILEN=$(echo "$API" | wc -m)
HOMEID=`cat /etc/enigma2/settings |grep config.plugins.airly.homeid= |sed 's/config.plugins.airly.homeid=//'`
HMODEID=`cat /etc/enigma2/settings |grep config.plugins.airly.hmodeid= |sed 's/config.plugins.airly.hmodeid=//'`
HOMELAT=`cat /etc/enigma2/settings |grep config.plugins.airly.homelat= |sed 's/config.plugins.airly.homelat=//'`
HOMELON=`cat /etc/enigma2/settings |grep config.plugins.airly.homelon= |sed 's/config.plugins.airly.homelon=//'`
HCITY=`cat /etc/enigma2/settings |grep config.plugins.airly.hcity= |sed 's/config.plugins.airly.hcity=//'`
HSTREET=`cat /etc/enigma2/settings |grep config.plugins.airly.hstreet= |sed 's/config.plugins.airly.hstreet=//'`
CTIMEOUT=`cat /etc/enigma2/settings |grep config.plugins.airly.ctimeout= |sed 's/config.plugins.airly.ctimeout=//'`
SFREQ=`cat /etc/enigma2/settings |grep config.plugins.airly.schedulerfrequency= |sed 's/config.plugins.airly.schedulerfrequency=//'`
LFILE='LOGOFF'
LOGFILE=/tmp/Airly/airly.log
if [ -e $LOGFILE ]; then
	LFILE="LOGON"
	if [ -z $SFREQ ]; then
		echo "$NOW --- scheduler.sh ---> Started (1.0-r46) every 15 min" >> $LOGFILE
	else
		echo "$NOW --- scheduler.sh ---> Started (1.0-r46) every $SFREQ min" >> $LOGFILE
	fi
	echo "$NOW --- scheduler.sh ---> APIlen:$APILEN" >> $LOGFILE
else
	logger -st Airly "scheduler.sh - Started (1.0-r46) every $SFREQ min"
fi

if [ -z "$CTIMEOUT" ]; then
	CTIMEOUT="10"
else
	CTIMEOUT=$CTIMEOUT
fi
if [ ! -z "$API" ]; then
	if [ -z "$HMODEID" ]; then
		/usr/bin/curl -m $CTIMEOUT -X GET --header "Accept: application/json" --header "Accept-Language: en" --header "apikey: $API"  "https://airapi.airly.eu/v2/measurements/point?includeWind=true&indexType=AIRLY_CAQI&lat=$HOMELAT&lng=$HOMELON" > /tmp/Airly/airly.sch
		sed -i 's/,"description.*/\n/g; s/{//g; s/}//g; s/"//g; s/\[//g; s/\]//g' /tmp/Airly/airly.sch
		sed -i 's/^.*values:/mode:interpolated,/g; s/indexes://g; s/,value//g; s/,/\n/g; s/name://g' /tmp/Airly/airly.sch
		if [ -z "$HCITY" ]; then
			HCITY="Warszawa"
		fi
		echo "city:$HCITY" >> /tmp/Airly/airly.sch
		echo "street:$HSTREET" >> /tmp/Airly/airly.sch
		if [ "$LFILE" == "LOGON" ]; then
			echo "$NOW --- scheduler.sh ---> Data collected by LAT/LON" >> $LOGFILE
		else
			logger -st Airly "Data collected by LAT/LON"
		fi
	else
		/usr/bin/curl -m $CTIMEOUT -X GET --header "Accept: application/json" --header "Accept-Language: en" --header "apikey: $API" "https://airapi.airly.eu/v2/installations/$HOMEID" > /tmp/Airly/airly.sch
		/usr/bin/curl -m $CTIMEOUT -X GET --header "Accept: application/json" --header "Accept-Language: en" --header "apikey: $API" "https://airapi.airly.eu/v2/measurements/installation?includeWind=true&indexType=AIRLY_CAQI&installationId=$HOMEID" >> /tmp/Airly/airly.sch
		sed -i 's/,"history.*//g; s/{//g; s/}//g; s/"//g; s/\[//g; s/\]//g' /tmp/Airly/airly.sch
		sed -i 's/location.*city/city/g; s/,displayAddress1.*,values:/,/g; s/indexes://g; s/,description.*//g; s/,value//g; s/,/\n/g; s/name://g' /tmp/Airly/airly.sch
		if [ "$LFILE" == "LOGON" ]; then
			echo "$NOW --- scheduler.sh ---> Data collected by ID" >> $LOGFILE
		else
			logger -st Airly "Data collected by ID"
		fi
	fi
else
	if [ "$LFILE" == "LOGON" ]; then
		echo "$NOW --- scheduler.sh ---> API key missing!" >> $LOGFILE
	else
		logger -st Airly "API key missing!"
	fi
	exit 1
fi
exit 0
