# -*- coding: UTF-8 -*-
#							  Airly
#					Based on http://map.airly.org
#							 1.0-r46
#
#	Copyright (C) 2021  Ampersand
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see https://www.gnu.org/licenses/.
#
from __init__ import *
from . import _
import os, re, sys, time, gettext, datetime, calendar, string, locale
from Components.ActionMap import ActionMap, NumberActionMap
from Components.AVSwitch import AVSwitch
from Components.config import *
from Components.ConfigList import ConfigList, ConfigListScreen
from Components.GUIComponent import GUIComponent
from Components.Label import Label
from Components.Language import language
from Components.MenuList import MenuList
from Components.MultiContent import MultiContentEntryText
from Components.Pixmap import Pixmap
from Components.ProgressBar import ProgressBar
from Components.Slider import Slider
from Components.Sources.List import List
from Components.Sources.StaticText import StaticText
from enigma import eConsoleAppContainer, eTimer, gFont, ePicLoad, gPixmapPtr, addFont, getDesktop, eListboxPythonMultiContent, RT_VALIGN_CENTER
from Plugins.Plugin import PluginDescriptor
from re import findall, search, split, sub
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.Standby import TryQuitMainloop
from Screens.VirtualKeyBoard import VirtualKeyBoard
from string import find, strip
from Tools.Directories import fileExists, resolveFilename, SCOPE_CONFIG, SCOPE_PLUGINS, copyfile
from skin import parseFont, parseColor
from twisted.web import client, error
from twisted.web.client import getPage, downloadPage
from urllib2 import Request, urlopen, URLError
from time import localtime, timezone, altzone
from os import system, path
from debug import print_dbg, clear_dbg, DBG_FILE

USR_PATH = resolveFilename(SCOPE_CONFIG)+"Airly"
PLUGIN_PATH = resolveFilename(SCOPE_PLUGINS, "Extensions/Airly")
lang = language.getLanguage()[:2]

if os.path.exists(USR_PATH) is False:
	try:
		os.makedirs(USR_PATH, 755)
	except:
		pass
		
if os.path.exists("/tmp/Airly") is False:
	try:
		os.makedirs("/tmp/Airly", 755)
	except:
		pass

def applySkinVars(skin, dict):
	for key in dict.keys():
		try:
			skin = skin.replace('{' + key + '}', dict[key])
		except Exception as e:
			print e, '@key=', key
	return skin

def transOutput(text):
	text = text.replace('Å', 'A')
	return text

CountryList = [('Poland', 'Poland'), ('Afghanistan', 'Afghanistan'), ('Algeria', 'Algeria'), ('Andorra', 'Andorra'), ('Angola', 'Angola'), ('Argentina', 'Argentina'), ('Armenia', 'Armenia'), ('Australia', 'Australia'),
 ('Austria', 'Austria'), ('Bahamas', 'Bahamas'), ('Bahrain', 'Bahrain'), ('Bangladesh', 'Bangladesh'), ('Belarus', 'Belarus'), ('Belgium', 'Belgium'), ('Belize', 'Belize'), ('Bermuda', 'Bermuda'),
 ('BiH', 'BiH'), ('Brazil', 'Brazil'), ('British Virgin Islands', 'British Virgin Islands'), ('Bulgaria', 'Bulgaria'), ('Canada', 'Canada'), ('Cape Verde', 'Cape Verde'),
 ('Chile', 'Chile'), ('China', 'China'), ('Colombia', 'Colombia'), ('Costa Rica', 'Costa Rica'), ('Croatia', 'Croatia'), ('Cyprus', 'Cyprus'), ('Czechia', 'Czechia'),
 ('Congo', 'Congo'), ('Denmark', 'Denmark'), ('East Timor', 'East Timor'), ('Ecuador', 'Ecuador'), ('Estonia', 'Estonia'), ('Ethiopia', 'Ethiopia'), ('Finland', 'Finland'), ('France', 'France'),
 ('Gambia', 'Gambia'), ('Georgia', 'Georgia'), ('Germany', 'Germany'), ('Ghana', 'Ghana'), ('Gibraltar', 'Gibraltar'), ('Greece', 'Greece'), ('Greenland', 'Greenland'),
 ('Grenada', 'Grenada'), ('Guatemala', 'Guatemala'), ('Guinea', 'Guinea'), ('Guyana', 'Guyana'), ('Honduras', 'Honduras'), ('Hungary', 'Hungary'), ('Iceland', 'Iceland'), ('India', 'India'),
 ('Indonesia', 'Indonesia'), ('Iraq', 'Iraq'), ('Ireland', 'Ireland'), ('Israel', 'Israel'), ('Italy', 'Italy'), ('Ivory Coast', 'Ivory Coast'), ('Japan', 'Japan'), ('Jersey', 'Jersey'), ('Jordan', 'Jordan'),
 ('Kazakhstan', 'Kazakhstan'), ('Kenya', 'Kenya'), ('Kosovo', 'Kosovo'), ('Kuwait', 'Kuwait'), ('Kyrgyzstan', 'Kyrgyzstan'), ('Laos', 'Laos'), ('Latvia', 'Latvia'), ('Lebanon', 'Lebanon'),
 ('Lithuania', 'Lithuania'), ('Luxembourg', 'Luxembourg'), ('Macedonia', 'Macedonia'), ('Madagascar', 'Madagascar'), ('Malaysia', 'Malaysia'), ('Mali', 'Mali'), ('Malta', 'Malta'), ('Mexico', 'Mexico'),
 ('Mongolia', 'Mongolia'), ('Morocco', 'Morocco'), ('Myanmar', 'Myanmar'), ('Nepal', 'Nepal'), ('New Zealand', 'New Zealand'), ('Nigeria', 'Nigeria'), ('Norway', 'Norway'), ('Pakistan', 'Pakistan'),
 ('Peru', 'Peru'), ('Philippines', 'Philippines'), ('Portugal', 'Portugal'), ('Romania', 'Romania'), ('Russia', 'Russia'), ('Saudi Arabia', 'Saudi Arabia'), ('Senegal', 'Senegal'), ('Serbia', 'Serbia'),
 ('Sierra Leone', 'Sierra Leone'), ('Singapore', 'Singapore'), ('Slovakia', 'Slovakia'), ('Slovenia', 'Slovenia'), ('South Africa', 'South Africa'), ('South Korea', 'South Korea'), ('Spain', 'Spain'),
 ('Sri Lanka', 'Sri Lanka'), ('Sudan', 'Sudan'), ('Sweden', 'Sweden'), ('Switzerland', 'Switzerland'), ('Taiwan', 'Taiwan'), ('Tajikistan', 'Tajikistan'), ('Thailand', 'Thailand'),
 ('The Netherlands', 'The Netherlands'), ('Togo', 'Togo'), ('Trinidad & Tobago', 'Trinidad & Tobago'), ('Turkey', 'Turkey'), ('Turkmenistan', 'Turkmenistan'), ('USA', 'USA'), ('Uganda', 'Uganda'),
 ('Ukraine', 'Ukraine'), ('UA Emirates', 'UA Emirates'), ('UK', 'UK'), ('Uzbekistan', 'Uzbekistan'), ('Vietnam', 'Vietnam'), ('off', _('Off'))]

config.plugins.airly = ConfigSubsection()
config.plugins.airly.hmodeid = ConfigYesNo(default=False)
config.plugins.airly.homeid = ConfigText(default='26', visible_width = 100, fixed_size = False)
config.plugins.airly.homelat = ConfigText(default="52.21930", visible_width = 100, fixed_size = False)
config.plugins.airly.homelon = ConfigText(default="21.00472", visible_width = 100, fixed_size = False)
config.plugins.airly.hcity = ConfigText(default="Warszawa", visible_width = 200, fixed_size = False)
config.plugins.airly.hstreet = ConfigText(default="Mikołajska", visible_width = 200, fixed_size = False)
config.plugins.airly.hcountry = ConfigSelection(default='Poland', choices = CountryList)
config.plugins.airly.fav1modeid = ConfigYesNo(default=False)
config.plugins.airly.fav1id = ConfigText(default='700', visible_width = 100, fixed_size = False)
config.plugins.airly.fav1lat = ConfigText(default="50.25971", visible_width = 100, fixed_size = False)
config.plugins.airly.fav1lon = ConfigText(default="19.01713", visible_width = 100, fixed_size = False)
config.plugins.airly.fav1city = ConfigText(default="Katowice", visible_width = 200, fixed_size = False)
config.plugins.airly.fav1street = ConfigText(default="3 Maja 21", visible_width = 200, fixed_size = False)
config.plugins.airly.fav1country = ConfigSelection(default='Poland', choices = CountryList)
config.plugins.airly.fav2modeid = ConfigYesNo(default=False)
config.plugins.airly.fav2id = ConfigText(default='204', visible_width = 100, fixed_size = False)
config.plugins.airly.fav2lat = ConfigText(default="50.06201", visible_width = 100, fixed_size = False)
config.plugins.airly.fav2lon = ConfigText(default="19.94098", visible_width = 100, fixed_size = False)
config.plugins.airly.fav2city = ConfigText(default="Kraków", visible_width = 200, fixed_size = False)
config.plugins.airly.fav2street = ConfigText(default="aleja Niepodległości", visible_width = 200, fixed_size = False)
config.plugins.airly.fav2country = ConfigSelection(default='Poland', choices = CountryList)
config.plugins.airly.windspeedunits = ConfigSelection(default='km', choices=[('km', 'km/h'), ('m', 'm/s')])
config.plugins.airly.background = ConfigSelection(default='1', choices=[('1', '1'), ('2', '2'), ('3', '3'), ('4', '4'), ('5', '5'), ('6', '6')])
config.plugins.airly.font = ConfigSelection(default='apf1', choices=[('apf1', 'APF 1'), ('apf2', 'APF 2'), ('apf3', 'APF 3')])
config.plugins.airly.citylabels = ConfigYesNo(default=False)
config.plugins.airly.transparency = ConfigSlider(default=255, limits=(100, 255))
config.plugins.airly.autocheck = ConfigYesNo(default=True)
config.plugins.airly.scheduler = ConfigYesNo(default=False)
config.plugins.airly.schedulerfrequency = ConfigSelection(default='55', choices=[('5', '5 min'), ('10', '10 min'), ('15', '15 min'), ('20', '20 min'), ('30', '30 min'), ('45', '45 min'), ('55', '55 min'),
																				('90', '90 min'), ('120', '120 min'), ('180', '180 min')])
config.plugins.airly.ctimeout = ConfigSelection(default='10', choices=[('5', '5 sek'), ('10', '10 sek'), ('15', '15 sek'), ('20', '20 sek'), ('30', '30 sek')])
config.plugins.airly.idlist = ConfigSelection(default='pl', choices=[('pl', _('Poland')), ('wr', _('World'))])
config.plugins.airly.logs = ConfigSelection(default='off', choices=[('off', _('Off')), ('dbg', _('System log')), ('file', DBG_FILE)])

for myFont in ( ('Sansation_Italic.ttf','AP_SansIt'), ('Briskn.ttf','AP_Title'), ('Roboto-Regular.ttf','AP_Regular'), ('EFNRobin.ttf',					'AP_Val1'), 
				('Monspacb.ttf','AP_Val_desc1'), ('Sansation_Regular.ttf','AP_Val2'), ('Sansation_Regular.ttf','AP_Val_desc2'),  ('Sansation_Bold.ttf','SanBold'),
				('DejaVuSansCondensed.ttf','AP_Val3'), ('DejaVuSansCondensed.ttf','AP_Val_desc3'), ('MyriadPro-Semibold.otf','SemiboldLCD')):
	try:
		addFont(PLUGIN_PATH + '/font/%s' % myFont[0] , myFont[1], 100, False)
	except Exception as ex:
		addFont(PLUGIN_PATH + '/font/%s' % myFont[0] , myFont[1], 100, False, 0)
		print_dbg('--- myFont --->', 'Exception loading font %s' % myFont[0]) #DBG


def writeAlpha(val):
	if fileExists('/proc/stb/video/alpha'):
		with open('/proc/stb/video/alpha', 'w') as f:
			f.write(val)
			f.close()
		
def _hideScreen(hideflag):
	if fileExists('/proc/stb/video/alpha'):
		if hideflag == True:
			hideflag = False
			count = 40
			while count > 0:
				count -= 1
				writeAlpha('%i' % (config.plugins.airly.transparency.value * count / 40))
		else:
			hideflag = True
			count = 0
			while count < 40:
				count += 1
				writeAlpha('%i' % (config.plugins.airly.transparency.value * count / 40))
	return hideflag


class AirlyPreview(Screen):
	clear_dbg()
	currPlace = 0
	skinFHD = """
		<screen name="AirlyPreviewFHD" position="0,0" size="1920,1080" flags="wfNoBorder" backgroundColor="#00000000" title="Airly">
			<widget position="0,0" size="1920,1080" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1920,1080" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="384,48" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="20,0" size="112,45" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="180,0" size="200,45" source="tlogo" render="Label" font="AP_Regular; 20" foregroundColor="#18FFFFFF" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1792,0" size="128,48" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1792,0" size="128,48" source="global.CurrentTime" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="95,100" size="40,40" name="countrypng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="100,110" size="350,350" name="indexback" alphatest="blend" transparent="1" zPosition="4" />
			<widget position="100,110" size="350,350" source="airqualityindex" render="Label" font="{font2}; 160" halign="center" valign="center" noWrap="1" transparent="1" zPosition="5" />
			<widget position="100,405" size="350,50" name="CAQI" font="AP_SansIt; 30" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="5" />
			<widget position="440,120" size="560,100" source="city" render="Label" font="AP_Title; 60" foregroundColor="#00db9326" noWrap="1" transparent="1" zPosition="5" />
			<widget position="500,200" size="500,100" source="street" render="Label" font="AP_SansIt; 45" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="500,330" size="500,200" source="ldesc" render="Label" font="{font2}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="100,600" size="900,40" name="ldesc1" font="{font2}; 30" foregroundColor="#00398717" halign="center" transparent="1" zPosition="5" />
			<widget position="100,640" size="900,500" name="ldesc2" font="{font2}; 30" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="100,800" size="900,50" name="ldesc3" font="{font2}; 30" foregroundColor="#00BE4624" halign="center" transparent="1" zPosition="5" />
			<widget position="120,480" size="250,70" name="PM25" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,555" size="250,70" name="PM10" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,630" size="250,70" name="PM1" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,705" size="350,55" name="Temperature" font="{font2}; 40" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,760" size="350,55" name="Pressure" font="{font2}; 40" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,815" size="350,55" name="Humidity" font="{font2}; 40" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="120,870" size="350,55" name="Wind" font="{font2}; 40" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="370,480" size="500,70" name="wpm25" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="370,480" size="500,70" name="wpm25high" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="370,555" size="500,70" name="wpm10" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="370,555" size="500,70" name="wpm10high" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="600,480" size="500,70" source="pm25" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,555" size="500,70" source="pm10" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,630" size="500,70" source="pm1" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,705" size="500,55" source="temperature" render="Label" font="{font1}; 40" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,760" size="500,55" source="pressure" render="Label" font="{font1}; 40" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,815" size="500,55" source="humidity" render="Label" font="{font1}; 40" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="600,870" size="500,55" source="wind" render="Label" font="{font1}; 40" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="100,950" size="60,30" name="menu" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="165,950" size="60,30" name="histogrampng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="165,950" size="130,30" name="SeID" font="{font2}; 22" foregroundColor="#FFFFFF" halign="right" noWrap="1" transparent="1" zPosition="5" />
			<widget position="295,950" size="450,30" source="seid" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="720,950" size="300,25" source="measurementtime" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" halign="right" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1140,130" size="650,120" source="GasTitle" render="Label" font="AP_Title; 50" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="1150,255" size="250,70" source="NO2" render="Label" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1530,255" size="500,70" source="no2" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1350,255" size="500,70" name="wno2" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="1350,255" size="500,70" name="wno2high" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="1150,330" size="250,70" source="O3" render="Label" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1530,330" size="500,70" source="o3" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1350,330" size="500,70" name="wo3" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="1350,330" size="500,70" name="wo3high" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="1150,405" size="250,70" source="SO2" render="Label" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1530,405" size="500,70" source="so2" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1350,405" size="500,70" name="wso2" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="1350,405" size="500,70" name="wso2high" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="1150,480" size="250,70" source="CO" render="Label" font="{font2}; 50" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1530,480" size="500,70" source="co" render="Label" font="{font1}; 50" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1350,480" size="500,70" name="wco" font="{font1}; 50" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="1350,480" size="500,70" name="wcohigh" font="{font1}; 50" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="1110,110" size="50,50" name="pm25png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1180,100" size="650,200" source="description1" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1110,270" size="50,50" name="pm10png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1180,260" size="650,200" source="description2" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1110,430" size="50,50" name="pm1png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1180,420" size="650,200" source="description3" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1110,620" size="50,50" name="caqipng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1180,610" size="650,300" source="description4" render="Label" font="{font2}; 22" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1140,850" size="650,50" name="caqibarpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1172,900" size="30,30" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1347,900" size="30,30" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1522,900" size="30,30" name="yellowpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1697,900" size="30,30" name="bluepng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1100,930" size="175,50" name="key_red" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1275,930" size="175,50" name="key_green" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1450,930" size="175,50" name="key_yellow" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1625,930" size="175,50" name="key_blue" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="0,1032" size="384,48" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1536,1032" size="384,48" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="20,1038" size="200,48" name="RateLimitDay" font="AP_Regular; 22" foregroundColor="#FFFFFF" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="220,1038" size="150,48" source="rtlimitday" render="Label" font="AP_Regular; 22" foregroundColor="#1839A0DB" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1590,1038" size="200,48" name="RateLimitMin" font="AP_Regular; 22" foregroundColor="#FFFFFF" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1810,1038" size="150,48" source="rtlimitmin" render="Label" font="AP_Regular; 22" foregroundColor="#1839A0DB" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
		</screen>"""
	skin = """
		<screen name="AirlyPreview" position="0,0" size="1280,720" flags="wfNoBorder" backgroundColor="#00000000" title="Airly">
			<widget position="0,0" size="1280,720" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1280,720" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="250,31" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="10,2" size="49,25" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="65,0" size="160,31" source="tlogo" render="Label" font="AP_Regular; 16" foregroundColor="#1839A0DB" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1197,0" size="83,31" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1197,0" size="83,31" source="global.CurrentTime" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,70" size="30,30" name="countrypng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="80,90" size="200,200" name="indexback" alphatest="blend" transparent="1" zPosition="4" />
			<widget position="80,90" size="200,200" source="airqualityindex" render="Label" font="{font2}; 100" backgroundColor="#ffffff" halign="center" valign="center" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,250" size="200,50" name="CAQI" font="AP_SansIt; 20" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="5" />
			<widget position="280,80" size="400,100" source="city" render="Label" font="AP_Title; 40" foregroundColor="#00db9326" noWrap="1" transparent="1" zPosition="5" />
			<widget position="330,140" size="350,100" source="street" render="Label" font="AP_SansIt; 35" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="330,230" size="350,200" source="ldesc" render="Label" font="{font2}; 20" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="80,370" size="600,40" name="ldesc1" font="{font2}; 20" foregroundColor="#00398717" halign="center" transparent="1" zPosition="5" />
			<widget position="80,400" size="600,200" name="ldesc2" font="{font2}; 20" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="80,510" size="600,50" name="ldesc3" font="{font2}; 20" foregroundColor="#00BE4624" halign="center" transparent="1" zPosition="5" />
			<widget position="80,340" size="250,70" name="PM25" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,380" size="250,70" name="PM10" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,420" size="250,70" name="PM1" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,460" size="250,30" name="Temperature" font="{font2}; 20" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,490" size="250,30" name="Pressure" font="{font2}; 20" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,520" size="250,30" name="Humidity" font="{font2}; 20" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="80,550" size="250,30" name="Wind" font="{font2}; 20" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="220,340" size="320,70" name="wpm25" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="220,340" size="320,70" name="wpm25high" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="220,380" size="320,70" name="wpm10" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="220,380" size="320,70" name="wpm10high" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="360,340" size="320,70" source="pm25" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,380" size="320,70" source="pm10" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,420" size="320,70" source="pm1" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,460" size="320,30" source="temperature" render="Label" font="{font1}; 20" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,490" size="320,30" source="pressure" render="Label" font="{font1}; 20" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,520" size="320,30" source="humidity" render="Label" font="{font1}; 20" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="360,550" size="320,30" source="wind" render="Label" font="{font1}; 20" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="70,630" size="40,20" name="menu" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="120,630" size="40,20" name="histogrampng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="100,630" size="130,30" name="SeID" font="{font2}; 14" foregroundColor="#FFFFFF" halign="right" noWrap="1" transparent="1" zPosition="5" />
			<widget position="230,630" size="450,30" source="seid" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="320,630" size="360,25" source="measurementtime" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" halign="right" noWrap="1" transparent="1" zPosition="5" />
			<widget position="755,80" size="450,80" source="GasTitle" render="Label" font="AP_Title; 30" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="750,170" size="250,70" source="NO2" render="Label" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1050,170" size="320,70" source="no2" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="900,170" size="320,70" name="wno2" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="900,170" size="320,70" name="wno2high" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="750,220" size="250,70" source="O3" render="Label" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1050,220" size="320,70" source="o3" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="900,220" size="320,70" name="wo3" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="900,220" size="320,70" name="wo3high" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="750,270" size="250,70" source="SO2" render="Label" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1050,270" size="320,70" source="so2" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="900,270" size="320,70" name="wso2" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="900,270" size="320,70" name="wso2high" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="750,320" size="250,70" source="CO" render="Label" font="{font2}; 30" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1050,320" size="320,70" source="co" render="Label" font="{font1}; 30" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="900,320" size="320,70" name="wco" font="{font1}; 30" foregroundColor="#389416" transparent="1" zPosition="5" />
			<widget position="900,320" size="320,70" name="wcohigh" font="{font1}; 30" foregroundColor="#ff4a3c" transparent="1" zPosition="5" />
			<widget position="740,80" size="50,50" name="pm25png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="800,70" size="430,200" source="description1" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="740,180" size="50,50" name="pm10png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="800,170" size="430,200" source="description2" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="740,290" size="50,50" name="pm1png" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="800,280" size="430,200" source="description3" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="740,415" size="50,50" name="caqipng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="800,405" size="430,300" source="description4" render="Label" font="{font2}; 14" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="755,570" size="450,35" name="caqibarpng" alphatest="blend" transparent="1" zPosition="6" />
			<widget position="782,600" size="20,20" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="907,600" size="20,20" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1032,600" size="20,20" name="yellowpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1157,600" size="20,20" name="bluepng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="730,620" size="125,40" name="key_red" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="855,620" size="125,40" name="key_green" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="980,620" size="125,40" name="key_yellow" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1105,620" size="125,40" name="key_blue" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="0,689" size="250,31" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1030,689" size="250,31" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="10,695" size="140,30" name="RateLimitDay" font="AP_Regular; 15" foregroundColor="#FFFFFF" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="150,695" size="100,30" source="rtlimitday" render="Label" font="AP_Regular; 15" foregroundColor="#1839A0DB" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1070,695" size="140,30" name="RateLimitMin" font="AP_Regular; 15" foregroundColor="#FFFFFF" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1210,695" size="140,30" source="rtlimitmin" render="Label" font="AP_Regular; 15" foregroundColor="#1839A0DB" halign="left" valign="center" noWrap="1" transparent="1" zPosition="2" />
		</screen>"""

	def __init__(self, session):
		writeAlpha('%i' % config.plugins.airly.transparency.value)
		global Home, Favourite1, Favourite2, IDPinnedToHome, IDPinnedToFav1, IDPinnedToFav2
		IDPinnedToHome = ''
		IDPinnedToFav1 = ''
		IDPinnedToFav2 = ''
		if fileExists(USR_PATH + "/home.cfg"):
			file = open(USR_PATH + "/home.cfg","r")
			Home = str(file.readline().strip())
			file.close()
		else:
			Home = config.plugins.airly.hcity.value
		if fileExists(USR_PATH + "/favourite1.cfg"):
			file = open(USR_PATH + "/favourite1.cfg","r")
			Favourite1 = str(file.readline().strip())
			file.close()
		else:
			Favourite1 = config.plugins.airly.fav1city.value
		if fileExists(USR_PATH + "/favourite2.cfg"):
			file = open(USR_PATH + "/favourite2.cfg","r")
			Favourite2 = str(file.readline().strip())
			file.close()
		else:
			Favourite2 = config.plugins.airly.fav2city.value
		self.version = '1.0-r46'
		print_dbg('+ Airly (%s) --->' % str(self.version), 'Started') #DBG
		if config.plugins.airly.font.value == 'apf1':
			font1 = 'AP_Val1'
			font2 = 'AP_Val_desc1'
		elif config.plugins.airly.font.value == 'apf2':
			font1 = 'AP_Val2'
			font2 = 'AP_Val_desc2'
		else:
			font1 = 'AP_Val3'
			font2 = 'AP_Val_desc3'
		self.dict = {'font1': font1, 'font2': font2}
		self.display_width = getDesktop(0).size().width()
		if self.display_width == 1920:
			self.skin = applySkinVars(AirlyPreview.skinFHD, self.dict)
		else:
			self.skin = applySkinVars(AirlyPreview.skin, self.dict)
		self.session = session
		Screen.__init__(self, session)
		self.title = 'Airly - ' + self.version
		self.hideflag = True
		self.apicheck = False
		self.apirate = False
		self['tlogo'] = StaticText(str(self.version))
		self['airlyback'] = Pixmap()
		self['infoback'] = Pixmap()
		self['indexback'] = Pixmap()
		self['header_l'] = Pixmap()
		self['footer_l'] = Pixmap()
		self['RateLimitDay'] = Label(_('API Daily Limit:'))
		self['RateLimitMin'] = Label(_('API Minute Limit:'))
		self['rtlimitday'] = StaticText()
		self['rtlimitmin'] = StaticText()
		self['alogo'] = Pixmap()
		self['header_r'] = Pixmap()
		self['footer_r'] = Pixmap()
		self['countrypng'] = Pixmap()
		self['pm25png'] = Pixmap()
		self['pm10png'] = Pixmap()
		self['pm1png'] = Pixmap()
		self['caqipng'] = Pixmap()
		self['caqibarpng'] = Pixmap()
		self['redpng'] = Pixmap()
		self['greenpng'] = Pixmap()
		self['yellowpng'] = Pixmap()
		self['bluepng'] = Pixmap()
		self['airqualityindex'] = StaticText()
		self['pollutionlevel'] = StaticText()
		self['ldesc'] = StaticText()
		self['ldesc1'] = Label()
		self['ldesc1'].hide()
		self['ldesc2'] = Label()
		self['ldesc2'].hide()
		self['ldesc3'] = Label()
		self['ldesc3'].hide()
		self['CAQI'] = Label('CAQI')
		self['CAQI'].hide()
		self['PM25'] = Label('PM2.5:')
		self['pm25'] = StaticText()
		self['PM10'] = Label('PM10:')
		self['pm10'] = StaticText()
		self['PM1'] = Label('PM1:')
		self['pm1'] = StaticText()
		self['wpm25'] = Label()
		self['wpm10'] = Label()
		self['wno2'] = Label()
		self['wo3'] = Label()
		self['wso2'] = Label()
		self['wco'] = Label()
		self['wpm25high'] = Label()
		self['wpm10high'] = Label()
		self['wno2high'] = Label()
		self['wo3high'] = Label()
		self['wso2high'] = Label()
		self['wcohigh'] = Label()
		self['Pressure'] = Label(_('Pressure:'))
		self['pressure'] = StaticText()
		self['Humidity'] = Label(_('Humidity:'))
		self['humidity'] = StaticText()
		self['Wind'] = Label(_('Wind:'))
		self['wind'] = StaticText()
		self['Temperature'] = Label(_('Temperature:'))
		self['temperature'] = StaticText()
		self['street'] = StaticText()
		self['strnr'] = StaticText()
		self['city'] = StaticText()
		self['measurementtime'] = StaticText()
		self['SeID'] = Label('ID:')
		self['seid'] = StaticText()
		self.apikey = ''
		self.ctimeout = config.plugins.airly.ctimeout.value
		self['description1'] = StaticText()
		self['description2'] = StaticText()
		self['description3'] = StaticText()
		self['description4'] = StaticText()
		self.pmunits = ' \xB5g/m\xB3'
		self.pmunits2 = '/m\xB3'
		sub2 = u'\u2082'
		sub3 = u'\u2083'
		self.sub2 = sub2.encode('utf-8')
		self.sub3 = sub3.encode('utf-8')
		self.tempunits = ' °C'
		self.huunits = ' %'
		self.preunits = ' hPa'
		self.windkmunits = ' km/h'
		self.windmunits = ' m/s'
		self['GasTitle'] = StaticText()
		self['NO2'] = StaticText()
		self['O3'] = StaticText()
		self['SO2'] = StaticText()
		self['CO'] = StaticText()
		self['no2'] = StaticText()
		self['o3'] = StaticText()
		self['so2'] = StaticText()
		self['co'] = StaticText()
		self['version'] = Label(self.version)
		if config.plugins.airly.homeid.value is not None:
			self.homeid = config.plugins.airly.homeid.value
		else:
			self.homeid = "26"
		if config.plugins.airly.fav1id.value is not None:
			self.fav1id= config.plugins.airly.fav1id.value
		else:
			self.fav1id = "700"
		if config.plugins.airly.fav2id.value is not None:
			self.fav2id = config.plugins.airly.fav2id.value
		else: 
			self.fav2id = "204"
		if config.plugins.airly.homelat.value is not None:
			self.hlat = config.plugins.airly.homelat.value
		else:
			self.hlat = "52.21930"
		if config.plugins.airly.homelon.value is not None:
			self.hlon = config.plugins.airly.homelon.value
		else:
			self.hlon = "21.00472"
		if config.plugins.airly.fav1lat.value is not None:
			self.f1lat = config.plugins.airly.fav1lat.value
		else: 
			self.f1lat = "50.25971"
		if config.plugins.airly.fav1lon.value is not None:
			self.f1lon = config.plugins.airly.fav1lon.value
		else:
			self.f1lon = "19.01713"
		if config.plugins.airly.fav2lat.value is not None:
			self.f2lat = config.plugins.airly.fav2lat.value
		else:
			self.f2lat = "50.06201"
		if config.plugins.airly.fav2lon.value is not None:
			self.f2lon = config.plugins.airly.fav2lon.value
		else:
			self.f2lon = "19.94098"
		self['menu'] = Pixmap()
		self['histogrampng'] = Pixmap()
		self['key_red'] = Label(_('Exit'))
		if config.plugins.airly.citylabels.value:
			self['key_green'] = Label(_(Favourite1))
			self['key_yellow'] = Label(_(Favourite2))
			self['key_blue'] = Label(_(Home))
		else:
			self['key_green'] = Label(_('Favourite 1'))
			self['key_yellow'] = Label(_('Favourite 2'))
			self['key_blue'] = Label(_('Home'))
		self['actions'] = ActionMap(['AirlyPreviewActions'], {
			'cancel': self.exit,
			'red': self.exit,
			'green': self.getFav1Page,
			'yellow': self.getFav2Page,
			'blue': self.getHomePage,
			'hideScreen': self.hideScreen,
			'showConfig': self.config,
			'showIDlist': self.idList,
			'ok': self.histogram,}, -2)
		self.setTitle(self.title)
		self.onClose.append(self.__onClose)
		self.onShow.append(self.apiKeyCheck)
		self.onShow.append(self.onLayoutFinished)

	def __onClose(self):
		AirlyPreview.currPlace = 0

	def onLayoutFinished(self):
		if fileExists('/tmp/Airly/airly.sch'):
			print_dbg('--- SchedulerDataFile --->', "SchedulerDataFile exists") #DBG
		else:
			print_dbg('--- SchedulerDataFile --->', "SchedulerDataFile does not exist") #DBG
		if config.plugins.airly.background.value == '1':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back1.png')
		elif config.plugins.airly.background.value == '2':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back2.png')
		elif config.plugins.airly.background.value == '3':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back3.png')
		elif config.plugins.airly.background.value == '4':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back4.png')
		elif config.plugins.airly.background.value == '5':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back5.png')
		elif config.plugins.airly.background.value == '6':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back6.png')
		self.loadPNG('infoback', PLUGIN_PATH + '/gfx/infoback.png')
		self.loadPNG('header_l', PLUGIN_PATH + '/gfx/header_l.png')
		self.loadPNG('footer_l', PLUGIN_PATH + '/gfx/footer_l.png')
		self.loadPNG('alogo', PLUGIN_PATH + '/gfx/alogo.png')
		self.loadPNG('header_r', PLUGIN_PATH + '/gfx/header_r.png')
		self.loadPNG('footer_r', PLUGIN_PATH + '/gfx/footer_r.png')
		self.loadPNG('menu', PLUGIN_PATH + '/gfx/buttons/menu.png')
		self.loadPNG('histogrampng', PLUGIN_PATH + '/gfx/buttons/ok.png')
		if lang == 'pl':
			if self.display_width == 1920:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_pl.png')
			else:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_pl_sd.png')
		elif lang == 'es':
			if self.display_width == 1920:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_es.png')
			else:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_es_sd.png')
		else:
			if self.display_width == 1920:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_en.png')
			else:
				self.loadPNG('caqibarpng', PLUGIN_PATH + '/gfx/other/caqibar_en_sd.png')
		self.loadPNG('redpng', PLUGIN_PATH + '/gfx/buttons/red.png')
		self.loadPNG('greenpng', PLUGIN_PATH + '/gfx/buttons/green.png')
		self.loadPNG('yellowpng', PLUGIN_PATH + '/gfx/buttons/yellow.png')
		self.loadPNG('bluepng', PLUGIN_PATH + '/gfx/buttons/blue.png')
		
		if AirlyPreview.currPlace == 0:
			self.getHomePage()
		elif AirlyPreview.currPlace == 1:
			self.getFav1Page()
		elif AirlyPreview.currPlace == 2:
			self.getFav2Page()

	def loadPNG(self, object, png):
		if os.path.exists(png):
			self.picload = ePicLoad()
			self[object].instance.setPixmap(gPixmapPtr())
			scale = AVSwitch().getFramebufferScale()
			size = self[object].instance.size()
			self.picload.setPara((size.width(), size.height(), scale[0], scale[0], False, 1, "#FF000000"))
			if self.picload.startDecode(png, 0, 0, False) == 0:
				ptr = self.picload.getData()
				if ptr != None:
					self[object].instance.setPixmap(ptr)
					self[object].show()
			del self.picload
			
	def apiKeyCheck(self):
		if fileExists(USR_PATH + "/api.txt"):
			file = open(USR_PATH + "/api.txt","r")
			self.apikey = str(file.readline().strip())
			file.close()
			if self.apikey != '':
				self.apikey == self.apikey
			else:
				print_dbg('--- apiKeyCheck-apikey --->', "API key missing!") #DBG
				self.apikey = '0'
		else:
			fwrite = open(USR_PATH + "/api.txt", "w")
			fwrite.close()
			print_dbg('--- apiKeyCheck-apikeyfile --->', "creating api.txt file!") #DBG
			self.apikey = '0'
		return self.apikey

	def idList(self):
		print_dbg('--- AirlyPreview-idList --->', 'goto AirlyIDList') #DBG
		self.session.open(AirlyIDList)

	def getHomePage(self):
		print_dbg('--- getHomePage --->', 'Started') #DBG
		AirlyPreview.currPlace = 0
		global Home, IDPinnedToHome
		self['ldesc1'].hide()
		self['ldesc2'].hide()
		self['ldesc3'].hide()
		self['CAQI'].hide()
		self['PM25'].hide()
		self['PM10'].hide()
		self['PM1'].hide()
		self['GasTitle'].text = ''
		self['NO2'].text = ''
		self['O3'].text = ''
		self['SO2'].text = ''
		self['CO'].text = ''
		self['wpm25'].hide()
		self['wpm10'].hide()
		self['wpm25high'].hide()
		self['wpm10high'].hide()
		self['wno2'].hide()
		self['wo3'].hide()
		self['wso2'].hide()
		self['wco'].hide()
		self['wno2high'].hide()
		self['wo3high'].hide()
		self['wso2high'].hide()
		self['wcohigh'].hide()
		self['Temperature'].hide()
		self['Pressure'].hide()
		self['Humidity'].hide()
		self['Wind'].hide()
		self['SeID'].hide()
		if fileExists('/var/lib/opkg/info/curl.control'):
			print_dbg('--- getHomePage-curl-status --->', "curl installed") #DBG
		else:
			print_dbg('--- getHomePage-curl-status --->', "curl not installed, starting installation...")
			try:
				os.system('opkg update && opkg install curl')
				if fileExists('/var/lib/opkg/info/curl.control'):
					print_dbg('--- getHomePage-curl-status --->', "curl installed successfully")
				else:
					print_dbg('--- getHomePage-curl-status --->', "curl installation failed")
			except:
				pass
		if config.plugins.airly.hmodeid.value:
			if IDPinnedToHome:
				self.homeid = IDPinnedToHome
				print_dbg('--- getHomePage-IDPinnedToHome --->', IDPinnedToHome) #DBG
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/installations/" + self.homeid + "' > /tmp/Airly/airly.out"
			cmd2 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/installation?includeWind=true&indexType=AIRLY_CAQI&installationId=" + self.homeid + "' >> /tmp/Airly/airly.out"
			system(cmd1)
			system(cmd2)
			print_dbg('--- getHomePage-id-cmd1 --->', str(cmd1)) #DBG
			print_dbg('--- getHomePage-id-cmd2 --->', str(cmd2)) #DBG
			IDPinnedToHome = ''
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out", "r+")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getHomePage-id-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getHomePage-id-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getHomePage-id-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getHomePage-id-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getHomePage-id-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getHomePage-id-info --->', info) #DBG
				
				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
			else:
				api_connection = False
		else:
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/point?includeWind=true&indexType=AIRLY_CAQI&lat=" + self.hlat + "&lng=" + self.hlon + "' > /tmp/Airly/airly.out"
			system(cmd1)
			print_dbg('--- getHomePage-noid-cmd1 --->', str(cmd1)) #DBG
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out", "r+")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getHomePage-noid-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getHomePage-noid-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getHomePage-noid-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getHomePage-noid-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getHomePage-noid-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getHomePage-noid-info --->', info) #DBG
		
				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
			else:
				api_connection = False

		if 'Invalid authentication credentials' in info_out or 'No API key found in request' in info_out or 'UNAUTHORIZED' in info_out:
			print_dbg('--- getHomePage-apicheck --->', "API key error!") #DBG
			self.apicheck = True
		if 'API rate limit exceeded' in info_out:
			print_dbg('--- getHomePage-apirate --->', "API rate limit exceeded!") #DBG
			self.apirate = True
		Airqualityindex = re.findall('name":"AIRLY_CAQI","value":(.*?),', info)
		try:
			airqualityindex = Airqualityindex[0].strip().split('.')[0]
			self['airqualityindex'].text = airqualityindex
			self['CAQI'].show()
		except:
			airqualityindex = ''
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
		print_dbg('--- getHomePage-airqualityindex --->', airqualityindex) #DBG
		PollutionLevel = re.findall('level":"(.*?)",', info)
		try:
			pollutionlevel = PollutionLevel[0].strip()
			self['pollutionlevel'].text = pollutionlevel
		except:
			pollutionlevel = ''
			self['pollutionlevel'].text = ''
		print_dbg('--- getHomePage-pollutionlevel --->', pollutionlevel) #DBG

		if config.plugins.airly.hmodeid.value:
			Country = re.findall('"country":"(.*?)",', info)
			try:
				country = Country[0].strip()
				print_dbg('--- getHomePage-country --->', country) #DBG
			except:
				country = ''
		else:
			country = config.plugins.airly.hcountry.value
		
		flagfile = PLUGIN_PATH + '/gfx/flags/' + country + '.png'
		print_dbg('--- getHomePage-flagfile --->', flagfile) #DBG
		try:
			if os.path.exists(flagfile):
				self.loadPNG('countrypng', flagfile)
			else:
				self['countrypng'].hide()
		except:
			pass

		if config.plugins.airly.hmodeid.value:
			City = re.findall('city":"(.*?)",', info)
			try:
				city = City[0].strip()
				length = len(city)
				if ', ' in city:
					city = city.split(',')[0]
				elif ' ' in city:
					city = city.split(' ')[0:2]
					if length > 17:
						if city[0] > 8:
							city1 = city[0] + ' ' + city[1][:9] + '.'
							city2 = city[0] + ' ' + city[1]
						else:
							city1 = city[0] + ' ' + city[1][:12] + '.'
							city2 = city[0] + ' ' + city[1]
					else:
						city1 = city[0] + ' ' + city[1]
						city2 = city[0] + ' ' + city[1]
				else:
					city1 = city
					city2 = city
				self['city'].text = city1
				Home = city2
				fwrite = open(USR_PATH + "/home.cfg", "w")
				fwrite.write(Home)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_blue'].hide()
					self['key_blue'].setText(Home)
					self['key_blue'].show()
				print_dbg('--- getHomePage-hmodeid-Home --->', Home) #DBG
			except:
				city = ''
				self['city'].text = ''
				Home = _('Home')
				fwrite = open(USR_PATH + "/home.cfg", "w")
				fwrite.write(Home)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_blue'].hide()
					self['key_blue'].setText(Home)
					self['key_blue'].show()
				print_dbg('--- getHomePage-except-Home --->', Home) #DBG
		else:
			city = ''
			self['city'].text = config.plugins.airly.hcity.value
			Home = config.plugins.airly.hcity.value
			fwrite = open(USR_PATH + "/home.cfg", "w")
			fwrite.write(Home)
			fwrite.close()
			if config.plugins.airly.citylabels.value:
				self['key_blue'].hide()
				self['key_blue'].setText(Home)
				self['key_blue'].show()
			print_dbg('--- getHomePage-else-Home --->', Home) #DBG

		Strnr = re.findall('"number":"(.*?)",', info)
		try:
			strnr = Strnr[0].strip()
			self['strnr'].text = strnr
		except:
			strnr = ''
			self['strnr'].text = ''
		print_dbg('--- getHomePage-strnr --->', strnr) #DBG
		try:
			if config.plugins.airly.hmodeid.value:
				Street = re.findall('street":"(.*?)",', info)
				street = Street[0].strip()
				self['street'].text = street + ' ' + strnr
			else:
				street = ''
				self['street'].text = config.plugins.airly.hstreet.value
			print_dbg('--- getHomePage-street --->', street) #DBG
		except:
			street = ''
			self['street'].text = ''

		PM25 = re.findall('PM25","value":(.*?)}', info)
		try:
			pm25 = PM25[0].strip()
			pm251 = PM25[0].strip().split('.')[0]
			pm252 = PM25[0].strip().split('.')[1]
			if int(pm252[0]) >= 5:
				pm25 = int(float(pm25))
				pm25 += 1
			else:
				pm25 = pm251
			pm25 = str(pm25) + self.pmunits
			self['pm25'].text = pm25
			self['PM25'].show()
		except:
			pm25 = ''
			self['pm25'].text = ''
			self['PM25'].hide()
		print_dbg('--- getHomePage-PM25 --->', pm25) #DBG
		WPM25 = re.findall('pollutant":"PM25","limit":15.00,"percent":(.*?),"averaging', info)
		try:
			wpm25 = WPM25[0].strip()
			wpm251 = WPM25[0].strip().split('.')[0]
			wpm252 = WPM25[0].strip().split('.')[1]
			if int(wpm252[0]) >= 5:
				wpm25 = int(float(wpm25))
				wpm25 += 1
			else:
				wpm25 = wpm251
			if int(wpm25) > 100:
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25high'].show()
			else:
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25'].show()
		except:
			wpm25 = ''
			self['wpm25'].text = ''
			self['wpm25high'].text = ''
		print_dbg('--- getHomePage-WPM25 --->', wpm25) #DBG
		PM10 = re.findall('PM10","value":(.*?)}', info)
		try:
			pm10 = PM10[0].strip()
			pm101 = PM10[0].strip().split('.')[0]
			pm102 = PM10[0].strip().split('.')[1]
			if int(pm102[0]) >= 5:
				pm10 = int(float(pm10))
				pm10 += 1
			else:
				pm10 = pm101
			pm10 = str(pm10) + self.pmunits
			self['pm10'].text = pm10
			self['PM10'].show()
		except:
			pm10 = ''
			self['pm10'].text = ''
			self['PM10'].hide()
		print_dbg('--- getHomePage-pm10 --->', pm10) #DBG
		WPM10 = re.findall('pollutant":"PM10","limit":45.00,"percent":(.*?),"averaging', info)
		try:
			wpm10 = WPM10[0].strip()
			wpm101 = WPM10[0].strip().split('.')[0]
			wpm102 = WPM10[0].strip().split('.')[1]
			if int(wpm102[0]) >= 5:
				wpm10 = int(float(wpm10))
				wpm10 += 1
			else:
				wpm10 = wpm101
			if int(wpm10) > 100:	
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10high'].show()
			else:
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10'].show()
		except:
			wpm10 = ''
			self['wpm10'].text = ''
			self['wpm10high'].text = ''
		print_dbg('--- getHomePage-WPM10 --->', wpm10) #DBG
		PM1 = re.findall('PM1","value":(.*?)}', info)
		try:
			pm1 = PM1[0].strip()
			pm11 = PM1[0].strip().split('.')[0]
			pm12 = PM1[0].strip().split('.')[1]
			if int(pm12[0]) >= 5:
				pm1 = int(float(pm1))
				pm1 += 1
			else:
				pm1 = pm11			
			pm1 = str(pm1) + self.pmunits
			self['pm1'].text = pm1
			self['PM1'].show()
		except:
			pm1 = ''
			self['pm1'].text = ''
			self['PM1'].hide()
		print_dbg('--- getHomePage-pm1 --->', pm1) #DBG
		Temperature = re.findall('TEMPERATURE","value":(.*?)}', info)
		try:
			temperature = Temperature[0].strip()
			temperature1 = Temperature[0].strip().split('.')[0]
			temperature2 = Temperature[0].strip().split('.')[1]
			if int(temperature2[0]) >= 5:
				if temperature.startswith('-'):
					temperature = int(float(temperature))
					temperature -= 1
				else:
					temperature = int(float(temperature))
					temperature += 1
			else:
				if temperature.startswith('-0'):
					temperature = temperature1[1]
				else:
					temperature = temperature1
			self['temperature'].text = str(temperature) + self.tempunits
			self['Temperature'].show()
		except:
			temperature = ''
			self['temperature'].text = ''
			self['Temperature'].hide()
		print_dbg('--- getHomePage-temperature --->', temperature) #DBG
		Pressure = re.findall('PRESSURE","value":(.*?)}', info)
		try:
			pressure = Pressure[0].strip()
			pressure1 = Pressure[0].strip().split('.')[0]
			pressure2 = Pressure[0].strip().split('.')[1]
			if int(pressure2[0]) >= 5:
				pressure = int(float(pressure))
				pressure += 1
			else:
				pressure = pressure1
			self['pressure'].text = str(pressure) + self.preunits
			self['Pressure'].show()
		except:
			pressure = ''
			self['pressure'].text = ''
			self['Pressure'].hide()
		print_dbg('--- getHomePage-pressure --->', pressure) #DBG
		Humidity = re.findall('HUMIDITY","value":(.*?)}', info)
		try:
			humidity = Humidity[0].strip()
			humidity1 = Humidity[0].strip().split('.')[0]
			humidity2 = Humidity[0].strip().split('.')[1]
			if int(humidity2[0]) >= 5:
				humidity = int(float(humidity))
				humidity += 1
			else:
				humidity = humidity1
			self['humidity'].text = str(humidity) + self.huunits
			self['Humidity'].show()
		except:
			humidity = ''
			self['humidity'].text = ''
			self['Humidity'].hide()
		print_dbg('--- getHomePage-humidity --->', humidity) #DBG
		WindBearing = re.findall('WIND_BEARING","value":(.*?)}', info)
		try:
			windbearing = WindBearing[0].strip()
			if int(float(windbearing)) >= 0.00 and int(float(windbearing)) < 22.50:
				windbearing = _('N')
			elif int(float(windbearing)) >= 22.50 and int(float(windbearing)) < 45.00:
				windbearing = _('NE')
			elif int(float(windbearing)) >= 45.00 and int(float(windbearing)) < 67.50:
				windbearing = _('EN')
			elif int(float(windbearing)) >= 67.50 and int(float(windbearing)) < 112.50:
				windbearing = _('E')
			elif int(float(windbearing)) >= 112.50 and int(float(windbearing)) < 135.00:
				windbearing = _('ES')
			elif int(float(windbearing)) >= 135.00 and int(float(windbearing)) < 157.50:
				windbearing = _('SE')
			elif int(float(windbearing)) >= 157.50 and int(float(windbearing)) < 202.50:
				windbearing = _('S')
			elif int(float(windbearing)) >= 202.50 and int(float(windbearing)) < 225.00:
				windbearing = _('SW')
			elif int(float(windbearing)) >= 225.00 and int(float(windbearing)) < 247.50:
				windbearing = _('WS')
			elif int(float(windbearing)) >= 247.50 and int(float(windbearing)) < 270.00:
				windbearing = _('W')
			elif int(float(windbearing)) >= 270.00 and int(float(windbearing)) < 315.00:
				windbearing = _('WN')
			elif int(float(windbearing)) >= 315.00 and int(float(windbearing)) < 337.50:
				windbearing = _('NW')
			elif int(float(windbearing)) >= 337.50 and int(float(windbearing)) < 360.00:
				windbearing = _('N')
			else:
				windbearing = ''
		except:
			windbearing = ''
		print_dbg('--- getHomePage-windbearing --->', windbearing) #DBG
		Wind = re.findall('WIND_SPEED","value":(.*?)}', info)
		try:
			wind = Wind[0].strip()
			wind1 = Wind[0].strip().split('.')[0]
			wind2 = Wind[0].strip().split('.')[1]
			if int(wind2[0]) >= 5:
				wind = int(float(wind))
				wind += 1
			else:
				wind = wind1
			print_dbg('--- getHomePage-windspeedunits.value --->', config.plugins.airly.windspeedunits.value) #DBG
			if config.plugins.airly.windspeedunits.value == 'km':
				self['wind'].text = str(wind) + self.windkmunits + ' ( ' + str(windbearing) + ' )'
			elif config.plugins.airly.windspeedunits.value == 'm':
				wind = wind * 1000/3600
				self['wind'].text = str(wind) + self.windmunits + ' ( ' + str(windbearing) + ' )'
			self['Wind'].show()
		except:
			wind = ''
			self['wind'].text = ''
			self['Wind'].hide()
		print_dbg('--- getHomePage-wind --->', wind) #DBG
		MeasurementTime = re.findall('tillDateTime":"(.*?)"', info)
		try:
			MeasurementTime = MeasurementTime[0].replace("T", " ").split('.')[0]
			TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
			utc = datetime.datetime.utcnow()
			utc = datetime.datetime.utcnow().strftime(MeasurementTime)
			timestamp = calendar.timegm((datetime.datetime.strptime(utc, TIME_FORMAT)).timetuple())
			local = datetime.datetime.fromtimestamp(timestamp).strftime(TIME_FORMAT)
			measurementtime = str(local)
			self['measurementtime'].text = str(local)
		except:
			measurementtime = ''
			self['measurementtime'].text = ''
		print_dbg('--- getHomePage-measurementtime --->', measurementtime) #DBG		
		try:
			if config.plugins.airly.hmodeid.value:
				SeID = re.findall('"id":(.*?),"location', info)
				seid = SeID[0].strip()
				self['seid'].text = str(seid)
			else:
				seid = ''
				self['seid'].text = (_('Interpolated measurement'))
			self['SeID'].show()
		except:
			seid = ''
			self['seid'].text = ''
			self['SeID'].hide()
		print_dbg('--- getHomePage-seid --->', str(seid)) #DBG
		NO2 = re.findall('NO2","value":(.*?)}', info)
		self['NO2'].text = 'NO' + self.sub2 + ':'
		try:
			no2 = NO2[0].strip()
			no21 = NO2[0].strip().split('.')[0]
			no22 = NO2[0].strip().split('.')[1]
			if int(no22[0]) >= 5:
				no2 = int(float(no2))
				no2 += 1
			else:
				no2 = no21
			no2 = str(no2) + self.pmunits
			self['no2'].text = no2
		except:
			no2 = ''
			self['no2'].text = ''
			self['NO2'].text = ''
		print_dbg('--- getHomePage-NO2 --->', no2) #DBG
		O3 = re.findall('O3","value":(.*?)}', info)
		self['O3'].text = 'O' + self.sub3 + ':'
		try:
			o3 = O3[0].strip()
			o31 = O3[0].strip().split('.')[0]
			o32 = O3[0].strip().split('.')[1]
			if int(o32[0]) >= 5:
				o3 = int(float(o3))
				o3 += 1
			else:
				o3 = o31
			o3 = str(o3) + self.pmunits
			self['o3'].text = o3
		except:
			o3 = ''
			self['o3'].text = ''
			self['O3'].text = ''
		print_dbg('--- getHomePage-O3 --->', o3) #DBG
		SO2 = re.findall('SO2","value":(.*?)}', info)
		self['SO2'].text = 'SO' + self.sub2 + ':'
		try:
			so2 = SO2[0].strip()
			so21 = SO2[0].strip().split('.')[0]
			so22 = SO2[0].strip().split('.')[1]
			if int(so22[0]) >= 5:
				so2 = int(float(so2))
				so2 += 1
			else:
				so2 = so21
			so2 = str(so2) + self.pmunits
			self['so2'].text = so2
		except:
			so2 = ''
			self['so2'].text = ''
			self['SO2'].text = ''
		print_dbg('--- getHomePage-SO2 --->', so2) #DBG
		CO = re.findall('CO","value":(.*?)}', info)
		self['CO'].text = 'CO:'
		try:
			co = CO[0].strip()
			co1 = CO[0].strip().split('.')[0]
			co2 = CO[0].strip().split('.')[1]
			if int(co2[0]) >= 5:
				co = int(float(co))
				co += 1
			else:
				co = co1
			co = str(co) + self.pmunits
			self['co'].text = co
		except:
			co = ''
			self['co'].text = ''
			self['CO'].text = ''
		print_dbg('--- getHomePage-CO --->', co) #DBG
		WNO2 = re.findall('pollutant":"NO2","limit":200.0,"percent":(.*?),"averaging', info)
		try:
			wno2 = WNO2[0].strip()
			wno21 = WNO2[0].strip().split('.')[0]
			wno22 = WNO2[0].strip().split('.')[1]
			if int(wno22[0]) >= 5:
				wno2 = int(float(wno2))
				wno2 += 1
			else:
				wno2 = wno21
			if int(wno2) > 100:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2high'].show()
			else:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2'].show()
		except:
			wno2 = ''
			self['wno2'].text = ''
			self['wno2high'].text = ''
		print_dbg('--- getHomePage-WNO2 --->', wno2) #DBG
		WO3 = re.findall('pollutant":"O3","limit":100.0,"percent":(.*?),"averaging', info)
		try:
			wo3 = WO3[0].strip()
			wo31 = WO3[0].strip().split('.')[0]
			wo32 = WO3[0].strip().split('.')[1]
			if int(wo32[0]) >= 5:
				wo3 = int(float(wo3))
				wo3 += 1
			else:
				wo3 = wo31
			if int(wo3) > 100:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3high'].show()
			else:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3'].show()
		except:
			wo3 = ''
			self['wo3'].text = ''
			self['wo3high'].text = ''
		print_dbg('--- getHomePage-WO3 --->', wo3) #DBG
		WSO2 = re.findall('pollutant":"SO2","limit":350.0,"percent":(.*?),"averaging', info)
		try:
			wso2 = WSO2[0].strip()
			wso21 = WSO2[0].strip().split('.')[0]
			wso22 = WSO2[0].strip().split('.')[1]
			if int(wso22[0]) >= 5:
				wso2 = int(float(wso2))
				wso2 += 1
			else:
				wso2 = wso21
			if int(wso2) > 100:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2high'].show()
			else:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2'].show()
		except:
			wso2 = ''
			self['wso2'].text = ''
			self['wso2high'].text = ''
		print_dbg('--- getHomePage-WSO2 --->', wso2) #DBG
		WCO = re.findall('pollutant":"CO","limit":30000.0,"percent":(.*?),"averaging', info)
		try:
			wco = WCO[0].strip()
			wco1 = WCO[0].strip().split('.')[0]
			wco2 = WCO[0].strip().split('.')[1]
			if int(wco2[0]) >= 5:
				wco = int(float(wco))
				wco += 1
			else:
				wco = wco1
			if int(wco) > 100:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wcohigh'].show()
			else:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wco'].show()
		except:
			wco = ''
			self['wco'].text = ''
			self['wcohigh'].text = ''
		print_dbg('--- getHomePage-WCO --->', wco) #DBG

		if no2 or o3 or so2 or co:
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['GasTitle'].text = (_('Gas concentration levels'))
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = (_("Gas standards we use in Airly:\n\n* NO%s - 200%s - hourly average\n* O%s - 100%s - eight-hour average\n* SO%s - 350%s - hourly average\n* CO - 30 mg%s - hourly average.") % (self.sub2, self.pmunits, self.sub3, self.pmunits, self.sub2,  self.pmunits, self.pmunits2))
		else:
			self['GasTitle'].text = ''
			self.loadPNG('pm25png', PLUGIN_PATH + '/gfx/other/pm25.png')
			self.loadPNG('pm10png', PLUGIN_PATH + '/gfx/other/pm10.png')
			self.loadPNG('pm1png', PLUGIN_PATH + '/gfx/other/pm1.png')
			self.loadPNG('caqipng', PLUGIN_PATH + '/gfx/other/caqi.png')
			self['caqibarpng'].show()
			self['description1'].text = (_("PM2.5 is an air pollution with a diameter of 2.5 micrometers (one thousandth millimeter) or less. These particles remain suspended in the air and do not disperse. Limit = 25.0")) + self.pmunits + "."
			self['description2'].text = (_("PM10 is 10 micrometers (one thousandth millimeter) in diameter. Particles of this size (PM10 or less) can penetrate the deepest parts of the lungs due to their small size. Limit = 50.0")) + self.pmunits + "."
			self['description3'].text = (_("PM1 are ultra-fine particles with an aerodynamic diameter of less than 0.1 micrometers. Ultra-fine dust is the most destructive variant of fine particles, as they penetrate the lungs directly into the bloodstream and spread into organs."))
			self['description4'].text = (_("CAQI is an indicator of hourly air quality. Its value tells you how clean or polluted the air is and how breathing such air affects health. The European scale (CAQI) consists of values from 0 to 100. The higher the value of the indicator, the greater the risk of negative health symptoms and bad mood."))

		if pollutionlevel == 'VERY_LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/1.png')
			self['ldesc'].text = (_('The perfect day for outdoor activity.'))
		elif pollutionlevel == 'LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/2.png')
			self['ldesc'].text = (_('Good air. You can go outside and enjoy the day.'))
		elif pollutionlevel == 'MEDIUM':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/3.png')
			self['ldesc'].text = (_('It was better. This is not the best day for outside activity.'))
		elif pollutionlevel == 'HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/4.png')
			self['ldesc'].text = (_('Poor air quality. It is better to stay at home today.'))
		elif pollutionlevel == 'VERY_HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/5.png')
			self['ldesc'].text = (_('Very poor air quality. Protect your lungs.'))
		elif pollutionlevel == 'EXTREME':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/6.png')
			self['ldesc'].text = (_('Extremely bad air quality. Do not go out without a mask.'))
		elif pollutionlevel == 'AIRMAGEDDON':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/7.png')
			self['ldesc'].text = (_('AIRMAGEDDON.\nDo not breathe...'))
		else:
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/0.png')
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
			self['PM25'].hide()
			self['PM10'].hide()
			self['Temperature'].hide()
			self['Pressure'].hide()
			self['Humidity'].hide()
			self['Wind'].hide()
			self['SeID'].hide()
			self['pm25'].text = ''
			self['pm10'].text = ''
			self['pm1'].text = ''
			self['GasTitle'].text = ''
			self['NO2'].text = ''
			self['no2'].text = ''
			self['SO2'].text = ''
			self['so2'].text = ''
			self['O3'].text = ''
			self['o3'].text = ''
			self['CO'].text = ''
			self['co'].text = ''
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['caqibarpng'].hide()
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = ''
			self['wpm25'].text = ''
			self['wpm10'].text = ''
			self['wpm25high'].text = ''
			self['wpm10high'].text = ''
			self['wno2'].text = ''
			self['wo3'].text = ''
			self['wso2'].text = ''
			self['wco'].text = ''
			self['wno2high'].text = ''
			self['wo3high'].text = ''
			self['wso2high'].text = ''
			self['wcohigh'].text = ''
			self['temperature'].text = ''
			self['pressure'].text = ''
			self['humidity'].text = ''
			self['wind'].text = ''
			self['seid'].text = ''
			self['city'].text = _('Airly')
			self['street'].text = '1.0-r46'
			if api_connection == True:
				if self.apicheck == False:
					if self.apirate == True:
						self['ldesc'].text = (_('API key limit exceeded.'))
						self['ldesc1'].text = (_('Minute limit: 50\nDaily limit: 100'))
						self['ldesc2'].text = (_('The daily limit is reduced every day at midnight, the minute limit every full minute.'))
						self['ldesc3'].text = ''
					else:
						self['ldesc'].text = (_('There are no data or no sensors in this location yet, but they may soon appear!'))
						self['ldesc1'].text = (_('Go to WiemCzymOddycham.pl'))
						self['ldesc2'].text = (_('Report or vote for the town you choose to receive the sensor.\nEncourage family and friends to cast their votes for a specific location!'))
						self['ldesc3'].text = (_('Check what you are breathing!'))
				else:
					self['ldesc'].text = (_('No API token !!!'))
					self['ldesc1'].text = (_('Go to https://developer.airly.org/login'))
					self['ldesc2'].text = (_('Register and get a free API token.\nCopy it and place it in the file\n/etc/enigma2/Airly/api.txt'))
					self['ldesc3'].text = (_('Close and reopen Airly!'))
			else:
				self['ldesc'].text = (_('Airly API server connection error!'))
				self['ldesc1'].text = (_('Either Airly server or ...'))
				self['ldesc2'].text = (_('... your internet connection is down.'))
				self['ldesc3'].text = ''
			self['ldesc1'].show()
			self['ldesc2'].show()
			self['ldesc3'].show()
		return

	def getFav1Page(self):
		print_dbg('--- getFav1Page --->', 'started') #DBG
		AirlyPreview.currPlace = 1
		global Favourite1, IDPinnedToFav1
		self['ldesc1'].hide()
		self['ldesc2'].hide()
		self['ldesc3'].hide()
		self['CAQI'].hide()
		self['PM25'].hide()
		self['PM10'].hide()
		self['PM1'].hide()
		self['GasTitle'].text = ''
		self['NO2'].text = ''
		self['O3'].text = ''
		self['SO2'].text = ''
		self['CO'].text = ''
		self['wpm25'].hide()
		self['wpm10'].hide()
		self['wpm25high'].hide()
		self['wpm10high'].hide()
		self['wno2'].hide()
		self['wo3'].hide()
		self['wso2'].hide()
		self['wco'].hide()
		self['wno2high'].hide()
		self['wo3high'].hide()
		self['wso2high'].hide()
		self['wcohigh'].hide()
		self['Temperature'].hide()
		self['Pressure'].hide()
		self['Humidity'].hide()
		self['Wind'].hide()
		self['SeID'].hide()
		if config.plugins.airly.fav1modeid.value:
			if IDPinnedToFav1:
				self.fav1id = IDPinnedToFav1
				print_dbg('--- getFav1Page-IDPinnedToFav1 --->', IDPinnedToFav1) #DBG
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/installations/" + self.fav1id + "' > /tmp/Airly/airly.out"
			cmd2 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/installation?includeWind=true&indexType=AIRLY_CAQI&installationId=" + self.fav1id + "' >> /tmp/Airly/airly.out"
			system(cmd1)
			system(cmd2)
			print_dbg('--- getFav1Page-id-cmd1 --->', str(cmd1)) #DBG
			print_dbg('--- getFav1Page-id-cmd2 --->', str(cmd2)) #DBG
			IDPinnedToFav1 = ''
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getFav1Page-id-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getFav1Page-id-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getFav1Page-id-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getFav1Page-id-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getFav1Page-id-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getFav1Page-id-info --->', info) #DBG

				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
		else:
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/point?includeWind=true&indexType=AIRLY_CAQI&lat=" + self.f1lat + "&lng=" + self.f1lon + "' > /tmp/Airly/airly.out"
			system(cmd1)
			print_dbg('--- getFav1Page-noid-cmd1 --->', str(cmd1)) #DBG
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out", "r+")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getFav1Page-noid-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getFav1Page-noid-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getFav1Page-noid-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getFav1Page-noid-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getFav1Page-noid-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getFav1Page-noid-info --->', info) #DBG

				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
			else:
				api_connection = False
			
		if 'Invalid authentication credentials' in info_out or 'No API key found in request' in info_out:
			print_dbg('--- getFav1Page-apicheck --->', "API key error!") #DBG
			self.apicheck = True
		if 'API rate limit exceeded' in info_out:
			print_dbg('--- getFav1Page-apirate --->', "API rate limit exceeded!") #DBG
			self.apirate = True
		Airqualityindex = re.findall('name":"AIRLY_CAQI","value":(.*?),', info)
		try:
			airqualityindex = Airqualityindex[0].strip().split('.')[0]
			self['airqualityindex'].text = airqualityindex
			self['CAQI'].show()
		except:
			airqualityindex = ''
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
		print_dbg('--- getFav1Page-airqualityindex --->', airqualityindex) #DBG
		PollutionLevel = re.findall('level":"(.*?)",', info)
		try:
			pollutionlevel = PollutionLevel[0].strip()
			self['pollutionlevel'].text = pollutionlevel
		except:
			pollutionlevel = ''
			self['pollutionlevel'].text = ''
		print_dbg('--- getFav1Page-pollutionlevel --->', pollutionlevel) #DBG

		if config.plugins.airly.fav1modeid.value:
			Country = re.findall('"country":"(.*?)",', info)
			try:
				country = Country[0].strip()
				print_dbg('--- getFav1Page-country --->', country) #DBG
			except:
				country =  ''
		else:
			country = config.plugins.airly.fav1country.value

		flagfile = PLUGIN_PATH + '/gfx/flags/' + country + '.png'
		print_dbg('--- getFav1Page-flagfile --->', flagfile) #DBG
		try:
			if os.path.exists(flagfile):
				self.loadPNG('countrypng', flagfile)
			else:
				self['countrypng'].hide()
		except:
			pass

		if config.plugins.airly.fav1modeid.value:
			City = re.findall('city":"(.*?)",', info)
			try:
				city = City[0].strip()
				length = len(city)
				if ', ' in city:
					city = city.split(',')[0]
				elif ' ' in city:
					city = city.split(' ')[0:2]
					if length > 17:
						if city[0] > 8:
							city1 = city[0] + ' ' + city[1][:9] + '.'
							city2 = city[0] + ' ' + city[1]
						else:
							city1 = city[0] + ' ' + city[1][:12] + '.'
							city2 = city[0] + ' ' + city[1]
					else:
						city1 = city[0] + ' ' + city[1]
						city2 = city[0] + ' ' + city[1]
				else:
					city1 = city
					city2 = city
				self['city'].text = city1
				Favourite1 = city2
				fwrite = open(USR_PATH + "/favourite1.cfg", "w")
				fwrite.write(Favourite1)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_green'].hide()
					self['key_green'].setText(Favourite1)
					self['key_green'].show()
				print_dbg('--- getFav1Page-fav1modeid-Favourite1 --->', Favourite1) #DBG
			except:
				city = ''
				self['city'].text = ''
				Favourite1 = _('Favourite 1')
				fwrite = open(USR_PATH + "/favourite1.cfg", "w")
				fwrite.write(Favourite1)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_green'].hide()
					self['key_green'].setText(Favourite1)
					self['key_green'].show()
				print_dbg('--- getFav1Page-except-Favourite1 --->', Favourite1) #DBG
		else:
			city = ''
			self['city'].text = config.plugins.airly.fav1city.value
			Favourite1 = config.plugins.airly.fav1city.value
			fwrite = open(USR_PATH + "/favourite1.cfg", "w")
			fwrite.write(Favourite1)
			fwrite.close()
			if config.plugins.airly.citylabels.value:
				self['key_green'].hide()
				self['key_green'].setText(Favourite1)
				self['key_green'].show()
			print_dbg('--- getFav1Page-else-Favourite1 --->', Favourite1) #DBG

		Strnr = re.findall('"number":"(.*?)",', info)
		try:
			strnr = Strnr[0].strip()
			self['strnr'].text = strnr
		except:
			strnr = ''
			self['strnr'].text = ''
		print_dbg('--- getFav1Page-strnr --->', strnr) #DBG
		try:
			if config.plugins.airly.fav1modeid.value:
				Street = re.findall('street":"(.*?)",', info)
				street = Street[0].strip()
				self['street'].text = street + ' ' + strnr
			else:
				street = ''
				self['street'].text = config.plugins.airly.fav1street.value
			print_dbg('--- getFav1Page-street --->', street) #DBG
		except:
			street = ''
			self['street'].text = ''
		PM25 = re.findall('PM25","value":(.*?)}', info)
		try:
			pm25 = PM25[0].strip()
			pm251 = PM25[0].strip().split('.')[0]
			pm252 = PM25[0].strip().split('.')[1]
			if int(pm252[0]) >= 5:
				pm25 = int(float(pm25))
				pm25 += 1
			else:
				pm25 = pm251
			pm25 = str(pm25) + self.pmunits
			self['pm25'].text = pm25
			self['PM25'].show()
		except:
			pm25 = ''
			self['pm25'].text = ''
			self['PM25'].hide()
		print_dbg('--- getFav1Page-PM25 --->', pm25) #DBG
		WPM25 = re.findall('pollutant":"PM25","limit":15.00,"percent":(.*?),"averaging', info)
		try:
			wpm25 = WPM25[0].strip()
			wpm251 = WPM25[0].strip().split('.')[0]
			wpm252 = WPM25[0].strip().split('.')[1]
			if int(wpm252[0]) >= 5:
				wpm25 = int(float(wpm25))
				wpm25 += 1
			else:
				wpm25 = wpm251
			if int(wpm25) > 100:				
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25high'].show()
			else:
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25'].show()
		except:
			wpm25 = ''
			self['wpm25'].text = ''
			self['wpm25high'].text = ''
		print_dbg('--- getFav1Page-WPM25 --->', wpm25) #DBG
		PM10 = re.findall('PM10","value":(.*?)}', info)
		try:
			pm10 = PM10[0].strip()
			pm101 = PM10[0].strip().split('.')[0]
			pm102 = PM10[0].strip().split('.')[1]
			if int(pm102[0]) >= 5:
				pm10 = int(float(pm10))
				pm10 += 1
			else:
				pm10 = pm101
			pm10 = str(pm10) + self.pmunits
			self['pm10'].text = pm10
			self['PM10'].show()
		except:
			pm10 = ''
			self['pm10'].text = ''
			self['PM10'].hide()
		print_dbg('--- getFav1Page-pm10 --->', pm10) #DBG
		WPM10 = re.findall('pollutant":"PM10","limit":45.00,"percent":(.*?),"averaging', info)
		try:
			wpm10 = WPM10[0].strip()
			wpm101 = WPM10[0].strip().split('.')[0]
			wpm102 = WPM10[0].strip().split('.')[1]
			if int(wpm102[0]) >= 5:
				wpm10 = int(float(wpm10))
				wpm10 += 1
			else:
				wpm10 = wpm101
			if int(wpm10) > 100:			
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10high'].show()
			else:
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10'].show()
		except:
			wpm10 = ''
			self['wpm10'].text = ''
			self['wpm10high'].text = ''
		print_dbg('--- getFav1Page-WPM10 --->', wpm10) #DBG
		PM1 = re.findall('PM1","value":(.*?)}', info)
		try:
			pm1 = PM1[0].strip()
			pm11 = PM1[0].strip().split('.')[0]
			pm12 = PM1[0].strip().split('.')[1]
			if int(pm12[0]) >= 5:
				pm1 = int(float(pm1))
				pm1 += 1
			else:
				pm1 = pm11			
			pm1 = str(pm1) + self.pmunits
			self['pm1'].text = pm1
			self['PM1'].show()
		except:
			pm1 = ''
			self['pm1'].text = ''
			self['PM1'].hide()
		print_dbg('--- getFav1Page-pm1 --->', pm1) #DBG
		Temperature = re.findall('TEMPERATURE","value":(.*?)}', info)
		try:
			temperature = Temperature[0].strip()
			temperature1 = Temperature[0].strip().split('.')[0]
			temperature2 = Temperature[0].strip().split('.')[1]
			if int(temperature2[0]) >= 5:
				if temperature.startswith('-'):
					temperature = int(float(temperature))
					temperature -= 1
				else:
					temperature = int(float(temperature))
					temperature += 1
			else:
				if temperature.startswith('-0'):
					temperature = temperature1[1]
				else:
					temperature = temperature1
			self['temperature'].text = str(temperature) + self.tempunits
			self['Temperature'].show()
		except:
			temperature = ''
			self['temperature'].text = ''
			self['Temperature'].hide()
		print_dbg('--- getFav1Page-temperature --->', temperature) #DBG
		Pressure = re.findall('PRESSURE","value":(.*?)}', info)
		try:
			pressure = Pressure[0].strip()
			pressure1 = Pressure[0].strip().split('.')[0]
			pressure2 = Pressure[0].strip().split('.')[1]
			if int(pressure2[0]) >= 5:
				pressure = int(float(pressure))
				pressure += 1
			else:
				pressure = pressure1
			self['pressure'].text = str(pressure) + self.preunits
			self['Pressure'].show()
		except:
			pressure = ''
			self['pressure'].text = ''
			self['Pressure'].hide()
		print_dbg('--- getFav1Page-pressure --->', pressure) #DBG
		Humidity = re.findall('HUMIDITY","value":(.*?)}', info)
		try:
			humidity = Humidity[0].strip()
			humidity1 = Humidity[0].strip().split('.')[0]
			humidity2 = Humidity[0].strip().split('.')[1]
			if int(humidity2[0]) >= 5:
				humidity = int(float(humidity))
				humidity += 1
			else:
				humidity = humidity1
			self['humidity'].text = str(humidity) + self.huunits
			self['Humidity'].show()
		except:
			humidity = ''
			self['humidity'].text = ''
			self['Humidity'].hide()
		print_dbg('--- getFav1Page-humidity --->', humidity) #DBG
		WindBearing = re.findall('WIND_BEARING","value":(.*?)}', info)
		try:
			windbearing = WindBearing[0].strip()
			if int(float(windbearing)) >= 0.00 and int(float(windbearing)) < 22.50:
				windbearing = _('N')
			elif int(float(windbearing)) >= 22.50 and int(float(windbearing)) < 45.00:
				windbearing = _('NE')
			elif int(float(windbearing)) >= 45.00 and int(float(windbearing)) < 67.50:
				windbearing = _('EN')
			elif int(float(windbearing)) >= 67.50 and int(float(windbearing)) < 112.50:
				windbearing = _('E')
			elif int(float(windbearing)) >= 112.50 and int(float(windbearing)) < 135.00:
				windbearing = _('ES')
			elif int(float(windbearing)) >= 135.00 and int(float(windbearing)) < 157.50:
				windbearing = _('SE')
			elif int(float(windbearing)) >= 157.50 and int(float(windbearing)) < 202.50:
				windbearing = _('S')
			elif int(float(windbearing)) >= 202.50 and int(float(windbearing)) < 225.00:
				windbearing = _('SW')
			elif int(float(windbearing)) >= 225.00 and int(float(windbearing)) < 247.50:
				windbearing = _('WS')
			elif int(float(windbearing)) >= 247.50 and int(float(windbearing)) < 270.00:
				windbearing = _('W')
			elif int(float(windbearing)) >= 270.00 and int(float(windbearing)) < 315.00:
				windbearing = _('WN')
			elif int(float(windbearing)) >= 315.00 and int(float(windbearing)) < 337.50:
				windbearing = _('NW')
			elif int(float(windbearing)) >= 337.50 and int(float(windbearing)) < 360.00:
				windbearing = _('N')
			else:
				windbearing = ''
		except:
			windbearing = ''
		print_dbg('--- getFav1Page-windbearing --->', windbearing) #DBG
		Wind = re.findall('WIND_SPEED","value":(.*?)}', info)
		try:
			wind = Wind[0].strip()
			wind1 = Wind[0].strip().split('.')[0]
			wind2 = Wind[0].strip().split('.')[1]
			if int(wind2[0]) >= 5:
				wind = int(float(wind))
				wind += 1
			else:
				wind = wind1
			print_dbg('--- getFav1Page-windspeedunits.value --->', config.plugins.airly.windspeedunits.value) #DBG
			if config.plugins.airly.windspeedunits.value == 'km':
				self['wind'].text = str(wind) + self.windkmunits + ' ( ' + str(windbearing) + ' )'
			elif config.plugins.airly.windspeedunits.value == 'm':
				wind = wind * 1000/3600
				self['wind'].text = str(wind) + self.windmunits + ' ( ' + str(windbearing) + ' )'
			self['Wind'].show()
		except:
			wind = ''
			self['wind'].text = ''
			self['Wind'].hide()
		print_dbg('--- getFav1Page-wind --->', wind) #DBG
		MeasurementTime = re.findall('tillDateTime":"(.*?)"', info)
		try:
			MeasurementTime = MeasurementTime[0].replace("T", " ").split('.')[0]
			TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
			utc = datetime.datetime.utcnow()
			utc = datetime.datetime.utcnow().strftime(MeasurementTime)
			timestamp = calendar.timegm((datetime.datetime.strptime(utc, TIME_FORMAT)).timetuple())
			local = datetime.datetime.fromtimestamp(timestamp).strftime(TIME_FORMAT)
			measurementtime = str(local)
			self['measurementtime'].text = str(local)
		except:
			measurementtime = ''
			self['measurementtime'].text = ''
		print_dbg('--- getFav1Page-measurementtime --->', measurementtime) #DBG		
		try:
			if config.plugins.airly.fav1modeid.value:
				SeID = re.findall('"id":(.*?),"location', info)
				seid = SeID[0].strip()
				self['seid'].text = str(seid)
			else:
				seid = ''
				self['seid'].text = (_('Interpolated measurement'))
			self['SeID'].show()
		except:
			seid = ''
			self['seid'].text = ''
			self['SeID'].hide()
		print_dbg('--- getFav1Page-seid --->', str(seid)) #DBG
		NO2 = re.findall('NO2","value":(.*?)}', info)
		self['NO2'].text = 'NO' + self.sub2 + ':'
		try:
			no2 = NO2[0].strip()
			no21 = NO2[0].strip().split('.')[0]
			no22 = NO2[0].strip().split('.')[1]
			if int(no22[0]) >= 5:
				no2 = int(float(no2))
				no2 += 1
			else:
				no2 = no21
			no2 = str(no2) + self.pmunits
			self['no2'].text = no2
		except:
			no2 = ''
			self['no2'].text = ''
			self['NO2'].text = ''
		print_dbg('--- getFav1Page-NO2 --->', no2) #DBG
		
		O3 = re.findall('O3","value":(.*?)}', info)
		self['O3'].text = 'O' + self.sub3 + ':'
		try:
			o3 = O3[0].strip()
			o31 = O3[0].strip().split('.')[0]
			o32 = O3[0].strip().split('.')[1]
			if int(o32[0]) >= 5:
				o3 = int(float(o3))
				o3 += 1
			else:
				o3 = o31
			o3 = str(o3) + self.pmunits
			self['o3'].text = o3
		except:
			o3 = ''
			self['o3'].text = ''
			self['O3'].text = ''
		print_dbg('--- getFav1Page-O3 --->', o3) #DBG
		
		SO2 = re.findall('SO2","value":(.*?)}', info)
		self['SO2'].text = 'SO' + self.sub2 + ':'
		try:
			so2 = SO2[0].strip()
			so21 = SO2[0].strip().split('.')[0]
			so22 = SO2[0].strip().split('.')[1]
			if int(so22[0]) >= 5:
				so2 = int(float(so2))
				so2 += 1
			else:
				so2 = so21
			so2 = str(so2) + self.pmunits
			self['so2'].text = so2
		except:
			so2 = ''
			self['so2'].text = ''
			self['SO2'].text = ''
		print_dbg('--- getFav1Page-SO2 --->', so2) #DBG

		CO = re.findall('CO","value":(.*?)}', info)
		self['CO'].text = 'CO:'
		try:
			co = CO[0].strip()
			co1 = CO[0].strip().split('.')[0]
			co2 = CO[0].strip().split('.')[1]
			if int(co2[0]) >= 5:
				co = int(float(co))
				co += 1
			else:
				co = co1
			co = str(co) + self.pmunits
			self['co'].text = co
		except:
			co = ''
			self['co'].text = ''
			self['CO'].text = ''
		print_dbg('--- getFav1Page-CO --->', co) #DBG
		WNO2 = re.findall('pollutant":"NO2","limit":200.0,"percent":(.*?),"averaging', info)
		try:
			wno2 = WNO2[0].strip()
			wno21 = WNO2[0].strip().split('.')[0]
			wno22 = WNO2[0].strip().split('.')[1]
			if int(wno22[0]) >= 5:
				wno2 = int(float(wno2))
				wno2 += 1
			else:
				wno2 = wno21
			if int(wno2) > 100:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2high'].show()
			else:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2'].show()
		except:
			wno2 = ''
			self['wno2'].text = ''
			self['wno2high'].text = ''
		print_dbg('--- getFav1Page-WNO2 --->', wno2) #DBG
		WO3 = re.findall('pollutant":"O3","limit":100.0,"percent":(.*?),"averaging', info)
		try:
			wo3 = WO3[0].strip()
			wo31 = WO3[0].strip().split('.')[0]
			wo32 = WO3[0].strip().split('.')[1]
			if int(wo32[0]) >= 5:
				wo3 = int(float(wo3))
				wo3 += 1
			else:
				wo3 = wo31
			if int(wo3) > 100:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3high'].show()
			else:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3'].show()
		except:
			wo3 = ''
			self['wo3'].text = ''
			self['wo3high'].text = ''
		print_dbg('--- getFav1Page-WO3 --->', wo3) #DBG
		WSO2 = re.findall('pollutant":"SO2","limit":350.0,"percent":(.*?),"averaging', info)
		try:
			wso2 = WSO2[0].strip()
			wso21 = WSO2[0].strip().split('.')[0]
			wso22 = WSO2[0].strip().split('.')[1]
			if int(wso22[0]) >= 5:
				wso2 = int(float(wso2))
				wso2 += 1
			else:
				wso2 = wso21
			if int(wso2) > 100:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2high'].show()
			else:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2'].show()
		except:
			wso2 = ''
			self['wso2'].text = ''
			self['wso2high'].text = ''
		print_dbg('--- getFav1Page-WSO2 --->', wso2) #DBG
		WCO = re.findall('pollutant":"CO","limit":30000.0,"percent":(.*?),"averaging', info)
		try:
			wco = WCO[0].strip()
			wco1 = WCO[0].strip().split('.')[0]
			wco2 = WCO[0].strip().split('.')[1]
			if int(wco2[0]) >= 5:
				wco = int(float(wco))
				wco += 1
			else:
				wco = wco1
			if int(wco) > 100:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wcohigh'].show()
			else:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wco'].show()
		except:
			wco = ''
			self['wco'].text = ''
			self['wcohigh'].text = ''
		print_dbg('--- getFav1Page-WCO --->', wco) #DBG
		
		if no2 or o3 or so2 or co:
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['GasTitle'].text = (_('Gas concentration levels'))
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = (_("Gas standards we use in Airly:\n\n* NO%s - 200%s - hourly average\n* O%s - 100%s - eight-hour average\n* SO%s - 350%s - hourly average\n* CO - 30 mg%s - hourly average.") % (self.sub2, self.pmunits, self.sub3, self.pmunits, self.sub2,  self.pmunits, self.pmunits2))
		else:
			self['GasTitle'].text = ''
			self.loadPNG('pm25png', PLUGIN_PATH + '/gfx/other/pm25.png')
			self.loadPNG('pm10png', PLUGIN_PATH + '/gfx/other/pm10.png')
			self.loadPNG('pm1png', PLUGIN_PATH + '/gfx/other/pm1.png')
			self.loadPNG('caqipng', PLUGIN_PATH + '/gfx/other/caqi.png')
			self['caqibarpng'].show()
			self['description1'].text = (_("PM2.5 is an air pollution with a diameter of 2.5 micrometers (one thousandth millimeter) or less. These particles remain suspended in the air and do not disperse. Limit = 25.0")) + self.pmunits + "."
			self['description2'].text = (_("PM10 is 10 micrometers (one thousandth millimeter) in diameter. Particles of this size (PM10 or less) can penetrate the deepest parts of the lungs due to their small size. Limit = 50.0")) + self.pmunits + "."
			self['description3'].text = (_("PM1 are ultra-fine particles with an aerodynamic diameter of less than 0.1 micrometers. Ultra-fine dust is the most destructive variant of fine particles, as they penetrate the lungs directly into the bloodstream and spread into organs."))
			self['description4'].text = (_("CAQI is an indicator of hourly air quality. Its value tells you how clean or polluted the air is and how breathing such air affects health. The European scale (CAQI) consists of values from 0 to 100. The higher the value of the indicator, the greater the risk of negative health symptoms and bad mood."))
		
		if pollutionlevel == 'VERY_LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/1.png')
			self['ldesc'].text = (_('The perfect day for outdoor activity.'))
		elif pollutionlevel == 'LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/2.png')
			self['ldesc'].text = (_('Good air. You can go outside and enjoy the day.'))
		elif pollutionlevel == 'MEDIUM':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/3.png')
			self['ldesc'].text = (_('It was better. This is not the best day for outside activity.'))
		elif pollutionlevel == 'HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/4.png')
			self['ldesc'].text = (_('Poor air quality. It is better to stay at home today.'))
		elif pollutionlevel == 'VERY_HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/5.png')
			self['ldesc'].text = (_('Very poor air quality. Protect your lungs.'))
		elif pollutionlevel == 'EXTREME':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/6.png')
			self['ldesc'].text = (_('Extremely bad air quality. Do not go out without a mask.'))
		elif pollutionlevel == 'AIRMAGEDDON':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/7.png')
			self['ldesc'].text = (_('AIRMAGEDDON.\nDo not breathe...'))
		else:
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/0.png')
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
			self['PM25'].hide()
			self['PM10'].hide()
			self['Temperature'].hide()
			self['Pressure'].hide()
			self['Humidity'].hide()
			self['Wind'].hide()
			self['SeID'].hide()
			self['pm25'].text = ''
			self['pm10'].text = ''
			self['pm1'].text = ''
			self['GasTitle'].text = ''
			self['NO2'].text = ''
			self['no2'].text = ''
			self['SO2'].text = ''
			self['so2'].text = ''
			self['O3'].text = ''
			self['o3'].text = ''
			self['CO'].text = ''
			self['co'].text = ''
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['caqibarpng'].hide()
			self['caqibarpng'].hide()
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = ''
			self['wpm25'].text = ''
			self['wpm10'].text = ''
			self['wpm25high'].text = ''
			self['wpm10high'].text = ''
			self['wno2'].text = ''
			self['wo3'].text = ''
			self['wso2'].text = ''
			self['wco'].text = ''
			self['wno2high'].text = ''
			self['wo3high'].text = ''
			self['wso2high'].text = ''
			self['wcohigh'].text = ''
			self['temperature'].text = ''
			self['pressure'].text = ''
			self['humidity'].text = ''
			self['wind'].text = ''
			self['seid'].text = ''
			self['city'].text = _('Airly')
			self['street'].text = '1.0-r46'
			if api_connection == True:
				if self.apicheck == False:
					if self.apirate == True:
						self['ldesc'].text = (_('API key limit exceeded.'))
						self['ldesc1'].text = (_('Minute limit: 50\nDaily limit: 100'))
						self['ldesc2'].text = (_('The daily limit is reduced every day at midnight, the minute limit every full minute.'))
						self['ldesc3'].text = ''
					else:
						self['ldesc'].text = (_('There are no data or no sensors in this location yet, but they may soon appear!'))
						self['ldesc1'].text = (_('Go to WiemCzymOddycham.pl'))
						self['ldesc2'].text = (_('Report or vote for the town you choose to receive the sensor.\nEncourage family and friends to cast their votes for a specific location!'))
						self['ldesc3'].text = (_('Check what you are breathing!'))
				else:
					self['ldesc'].text = (_('No API token !!!'))
					self['ldesc1'].text = (_('Go to https://developer.airly.org/login'))
					self['ldesc2'].text = (_('Register and get a free API token.\nCopy it and place it in the file\n/etc/enigma2/Airly/api.txt'))
					self['ldesc3'].text = (_('Close and reopen Airly!'))
			else:
				self['ldesc'].text = (_('Airly API server connection error!'))
				self['ldesc1'].text = (_('Either Airly server or ...'))
				self['ldesc2'].text = (_('... your internet connection is down.'))
				self['ldesc3'].text = ''
			self['ldesc1'].show()
			self['ldesc2'].show()
			self['ldesc3'].show()
		return

	def getFav2Page(self):
		print_dbg('--- getFav2Page --->', 'started') #DBG
		AirlyPreview.currPlace = 2
		global Favourite2, IDPinnedToFav2
		self['ldesc1'].hide()
		self['ldesc2'].hide()
		self['ldesc3'].hide()
		self['CAQI'].hide()
		self['PM25'].hide()
		self['PM10'].hide()
		self['PM1'].hide()
		self['GasTitle'].text = ''
		self['NO2'].text = ''
		self['O3'].text = ''
		self['SO2'].text = ''
		self['CO'].text = ''
		self['wpm25'].hide()
		self['wpm10'].hide()
		self['wpm25high'].hide()
		self['wpm10high'].hide()
		self['wno2'].hide()
		self['wo3'].hide()
		self['wso2'].hide()
		self['wco'].hide()
		self['wno2high'].hide()
		self['wo3high'].hide()
		self['wso2high'].hide()
		self['wcohigh'].hide()
		self['Temperature'].hide()
		self['Pressure'].hide()
		self['Humidity'].hide()
		self['Wind'].hide()
		self['SeID'].hide()
		if config.plugins.airly.fav2modeid.value:
			if IDPinnedToFav2:
				self.fav2id = IDPinnedToFav2
				print_dbg('--- getFav2Page-IDPinnedToFav2 --->', IDPinnedToFav2) #DBG
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/installations/" + self.fav2id + "' > /tmp/Airly/airly.out"
			cmd2 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/installation?includeWind=true&indexType=AIRLY_CAQI&installationId=" + self.fav2id + "' >> /tmp/Airly/airly.out"
			system(cmd1)
			system(cmd2)
			print_dbg('--- getFav2Page-id-cmd1 --->', str(cmd1)) #DBG
			print_dbg('--- getFav2Page-id-cmd2 --->', str(cmd2)) #DBG
			IDPinnedToFav2 = ''
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getFav2Page-id-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getFav2Page-id-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getFav2Page-id-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getFav2Page-id-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getFav2Page-id-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getFav2Page-id-info --->', info) #DBG

				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
		else:
			cmd1 = "/usr/bin/curl -m " + self.ctimeout + " -D /tmp/Airly/header -X GET --header 'Accept: application/json' --header 'Accept-Language: en' --header 'apikey: " + self.apikey +  "' 'https://airapi.airly.eu/v2/measurements/point?includeWind=true&indexType=AIRLY_CAQI&lat=" + self.f2lat + "&lng=" + self.f2lon + "' > /tmp/Airly/airly.out"
			system(cmd1)
			print_dbg('--- getFav2Page-url-cmd1 --->', str(cmd1)) #DBG
			if os.path.exists("/tmp/Airly/airly.out"):
				f = open("/tmp/Airly/airly.out", "r+")
				info_out = f.read()
				cur_startpos = info_out.find('{"')
				cur_endpos = info_out.find('history')
				info_cut = info_out[cur_startpos:cur_endpos]
				f.close()
				info = transOutput(info_cut)
			if os.path.exists("/tmp/Airly/header") and not os.stat("/tmp/Airly/header").st_size == 0:
				api_connection = True
				f = open("/tmp/Airly/header", "r+")
				head_out = f.read().replace('\r\n', ', ')
				f.close()
				print_dbg('--- getFav2Page-noid-head_out --->', head_out) #DBG
				try:
					RateLimitDay = re.findall('X-RateLimit-Limit-Day: (.*?),', head_out)
					RateLimitDayRemaining = re.findall('X-RateLimit-Remaining-Day: (.*?),', head_out)
					RateLimitDayMinute = re.findall('X-RateLimit-Limit-Minute: (.*?),', head_out)
					RateLimitDayMinuteRemaining = re.findall('X-RateLimit-Remaining-Minute: (.*?),', head_out)
				except:
					RateLimitDay = ''
					RateLimitDayRemaining = ''
					RateLimitDayMinute = ''
					RateLimitDayMinuteRemaining = ''
				print_dbg('--- getFav2Page-noid-RateLimitDay --->', RateLimitDay) #DBG
				print_dbg('--- getFav2Page-noid-RateLimitDayRemaining --->', RateLimitDayRemaining) #DBG
				print_dbg('--- getFav2Page-noid-RateLimitDayMinute --->', RateLimitDayMinute) #DBG
				print_dbg('--- getFav2Page-noid-RateLimitDayMinuteRemaining --->', RateLimitDayMinuteRemaining) #DBG
				print_dbg('--- getFav2Page-noid-info --->', info) #DBG

				if RateLimitDayRemaining and RateLimitDay:
					self['RateLimitDay'].show()
					rtlimitday = RateLimitDayRemaining[0].strip() + ' / ' + RateLimitDay[0].strip()
					self['rtlimitday'].text = rtlimitday
				else:
					self['RateLimitDay'].hide()
					self['rtlimitday'].text = ''
				if RateLimitDayMinuteRemaining and RateLimitDayMinute:
					self['RateLimitMin'].show()
					rtlimitmin = RateLimitDayMinuteRemaining[0].strip() + ' / ' + RateLimitDayMinute[0].strip()
					self['rtlimitmin'].text = rtlimitmin
				else:
					self['RateLimitMin'].hide()
					self['rtlimitmin'].text = ''
			else:
				api_connection = False

		if 'Invalid authentication credentials' in info_out or 'No API key found in request' in info_out:
			print_dbg('--- getFav2Page-apicheck --->', "API key error!") #DBG
			self.apicheck = True
		if 'API rate limit exceeded' in info_out:
			print_dbg('--- getFav2Page-apirate --->', "API rate limit exceeded!") #DBG
			self.apirate = True
		Airqualityindex = re.findall('name":"AIRLY_CAQI","value":(.*?),', info)
		try:
			airqualityindex = Airqualityindex[0].strip().split('.')[0]
			self['airqualityindex'].text = airqualityindex
			self['CAQI'].show()
		except:
			airqualityindex = ''
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
		print_dbg('--- getFav2Page-airqualityindex --->', airqualityindex) #DBG
		PollutionLevel = re.findall('level":"(.*?)",', info)
		try:
			pollutionlevel = PollutionLevel[0].strip()
			self['pollutionlevel'].text = pollutionlevel
		except:
			pollutionlevel = ''
			self['pollutionlevel'].text = ''
		print_dbg('--- getFav2Page-pollutionlevel --->', pollutionlevel) #DBG

		if config.plugins.airly.fav2modeid.value:
			Country = re.findall('"country":"(.*?)",', info)
			try:
				country = Country[0].strip()
				print_dbg('--- getFav2Page-country --->', country) #DBG
			except:
				country =  ''
		else:
			country = config.plugins.airly.fav2country.value

		flagfile = PLUGIN_PATH + '/gfx/flags/' + country + '.png'
		print_dbg('--- getFav2Page-flagfile --->', flagfile) #DBG
		try:
			if os.path.exists(flagfile):
				self.loadPNG('countrypng', flagfile)
			else:
				self['countrypng'].hide()
		except:
			pass

		if config.plugins.airly.fav2modeid.value:
			City = re.findall('city":"(.*?)",', info)
			try:
				city = City[0].strip()
				length = len(city)
				if ', ' in city:
					city = city.split(',')[0]
				elif ' ' in city:
					city = city.split(' ')[0:2]
					if length > 17:
						if city[0] > 8:
							city1 = city[0] + ' ' + city[1][:9] + '.'
							city2 = city[0] + ' ' + city[1]
						else:
							city1 = city[0] + ' ' + city[1][:12] + '.'
							city2 = city[0] + ' ' + city[1]
					else:
						city1 = city[0] + ' ' + city[1]
						city2 = city[0] + ' ' + city[1]
				else:
					city1 = city
					city2 = city
				self['city'].text = city1
				Favourite2 = city2
				fwrite = open(USR_PATH + "/favourite2.cfg", "w")
				fwrite.write(Favourite2)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_yellow'].hide()
					self['key_yellow'].setText(Favourite2)
					self['key_yellow'].show()
				print_dbg('--- getFav2Page-fav2modeid-Favourite2 --->', Favourite2) #DBG
			except:
				city = ''
				self['city'].text = ''
				Favourite2 = _('Favourite 2')
				fwrite = open(USR_PATH + "/favourite2.cfg", "w")
				fwrite.write(Favourite2)
				fwrite.close()
				if config.plugins.airly.citylabels.value:
					self['key_yellow'].hide()
					self['key_yellow'].setText(Favourite2)
					self['key_yellow'].show()
				print_dbg('--- getFav2Page-except-Favourite2 --->', Favourite2) #DBG
		else:
			city = ''
			self['city'].text = config.plugins.airly.fav2city.value
			Favourite2 = config.plugins.airly.fav2city.value
			fwrite = open(USR_PATH + "/favourite2.cfg", "w")
			fwrite.write(Favourite2)
			fwrite.close()
			if config.plugins.airly.citylabels.value:
				self['key_yellow'].hide()
				self['key_yellow'].setText(Favourite2)
				self['key_yellow'].show()
			print_dbg('--- getFav2Page-else-Favourite2 --->', Favourite2) #DBG

		Strnr = re.findall('"number":"(.*?)",', info)
		try:
			strnr = Strnr[0].strip()
			self['strnr'].text = strnr
		except:
			strnr = ''
			self['strnr'].text = ''
		print_dbg('--- getFav2Page-strnr --->', strnr) #DBG
		try:
			if config.plugins.airly.fav2modeid.value:
				Street = re.findall('street":"(.*?)",', info)
				street = Street[0].strip()
				self['street'].text = street + ' ' + strnr
			else:
				street = ''
				self['street'].text = config.plugins.airly.fav2street.value
			print_dbg('--- getFav2Page-street --->', street) #DBG
		except:
			street = ''
			self['street'].text = ''
		PM25 = re.findall('PM25","value":(.*?)}', info)
		try:
			pm25 = PM25[0].strip()
			pm251 = PM25[0].strip().split('.')[0]
			pm252 = PM25[0].strip().split('.')[1]
			if int(pm252[0]) >= 5:
				pm25 = int(float(pm25))
				pm25 += 1
			else:
				pm25 = pm251
			pm25 = str(pm25) + self.pmunits
			self['pm25'].text = pm25
			self['PM25'].show()
		except:
			pm25 = ''
			self['pm25'].text = ''
			self['PM25'].hide()
		print_dbg('--- getFav2Page-PM25 --->', pm25) #DBG
		WPM25 = re.findall('pollutant":"PM25","limit":15.00,"percent":(.*?),"averaging', info)
		try:
			wpm25 = WPM25[0].strip()
			wpm251 = WPM25[0].strip().split('.')[0]
			wpm252 = WPM25[0].strip().split('.')[1]
			if int(wpm252[0]) >= 5:
				wpm25 = int(float(wpm25))
				wpm25 += 1
			else:
				wpm25 = wpm251
			if int(wpm25) > 100:				
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25high'].show()
			else:
				wpm25 = str(wpm25) + self.huunits
				self['wpm25'].text = wpm25
				self['wpm25high'].text = wpm25
				self['wpm25'].show()
		except:
			wpm25 = ''
			self['wpm25'].text = ''
			self['wpm25high'].text = ''
		print_dbg('--- getFav2Page-WPM25 --->', wpm25) #DBG
		PM10 = re.findall('PM10","value":(.*?)}', info)
		try:
			pm10 = PM10[0].strip()
			pm101 = PM10[0].strip().split('.')[0]
			pm102 = PM10[0].strip().split('.')[1]
			if int(pm102[0]) >= 5:
				pm10 = int(float(pm10))
				pm10 += 1
			else:
				pm10 = pm101
			pm10 = str(pm10) + self.pmunits
			self['pm10'].text = pm10
			self['PM10'].show()
		except:
			pm10 = ''
			self['pm10'].text = ''
			self['PM10'].hide()
		print_dbg('--- getFav2Page-pm10 --->', pm10) #DBG
		WPM10 = re.findall('pollutant":"PM10","limit":45.00,"percent":(.*?),"averaging', info)
		try:
			wpm10 = WPM10[0].strip()
			wpm101 = WPM10[0].strip().split('.')[0]
			wpm102 = WPM10[0].strip().split('.')[1]
			if int(wpm102[0]) >= 5:
				wpm10 = int(float(wpm10))
				wpm10 += 1
			else:
				wpm10 = wpm101
			if int(wpm10) > 100:				
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10high'].show()
			else:
				wpm10 = str(wpm10) + self.huunits
				self['wpm10'].text = wpm10
				self['wpm10high'].text = wpm10
				self['wpm10'].show()
		except:
			wpm10 = ''
			self['wpm10'].text = ''
			self['wpm10high'].text = ''
		print_dbg('--- getFav2Page-WPM10 --->', wpm10) #DBG
		PM1 = re.findall('PM1","value":(.*?)}', info)
		try:
			pm1 = PM1[0].strip()
			pm11 = PM1[0].strip().split('.')[0]
			pm12 = PM1[0].strip().split('.')[1]
			if int(pm12[0]) >= 5:
				pm1 = int(float(pm1))
				pm1 += 1
			else:
				pm1 = pm11			
			pm1 = str(pm1) + self.pmunits
			self['pm1'].text = pm1
			self['PM1'].show()
		except:
			pm1 = ''
			self['pm1'].text = ''
			self['PM1'].hide()
		print_dbg('--- getFav2Page-pm1 --->', pm1) #DBG
		Temperature = re.findall('TEMPERATURE","value":(.*?)}', info)
		try:
			temperature = Temperature[0].strip()
			temperature1 = Temperature[0].strip().split('.')[0]
			temperature2 = Temperature[0].strip().split('.')[1]
			if int(temperature2[0]) >= 5:
				if temperature.startswith('-'):
					temperature = int(float(temperature))
					temperature -= 1
				else:
					temperature = int(float(temperature))
					temperature += 1
			else:
				if temperature.startswith('-0'):
					temperature = temperature1[1]
				else:
					temperature = temperature1
			self['temperature'].text = str(temperature) + self.tempunits
			self['Temperature'].show()
		except:
			temperature = ''
			self['temperature'].text = ''
			self['Temperature'].hide()
		print_dbg('--- getFav2Page-temperature --->', temperature) #DBG
		Pressure = re.findall('PRESSURE","value":(.*?)}', info)
		try:
			pressure = Pressure[0].strip()
			pressure1 = Pressure[0].strip().split('.')[0]
			pressure2 = Pressure[0].strip().split('.')[1]
			if int(pressure2[0]) >= 5:
				pressure = int(float(pressure))
				pressure += 1
			else:
				pressure = pressure1
			self['pressure'].text = str(pressure) + self.preunits
			self['Pressure'].show()
		except:
			pressure = ''
			self['pressure'].text = ''
			self['Pressure'].hide()
		print_dbg('--- getFav2Page-pressure --->', pressure) #DBG
		Humidity = re.findall('HUMIDITY","value":(.*?)}', info)
		try:
			humidity = Humidity[0].strip()
			humidity1 = Humidity[0].strip().split('.')[0]
			humidity2 = Humidity[0].strip().split('.')[1]
			if int(humidity2[0]) >= 5:
				humidity = int(float(humidity))
				humidity += 1
			else:
				humidity = humidity1
			self['humidity'].text = str(humidity) + self.huunits
			self['Humidity'].show()
		except:
			humidity = ''
			self['humidity'].text = ''
			self['Humidity'].hide()
		print_dbg('--- getFav2Page-humidity --->', humidity) #DBG
		WindBearing = re.findall('WIND_BEARING","value":(.*?)}', info)
		try:
			windbearing = WindBearing[0].strip()
			if int(float(windbearing)) >= 0.00 and int(float(windbearing)) < 22.50:
				windbearing = _('N')
			elif int(float(windbearing)) >= 22.50 and int(float(windbearing)) < 45.00:
				windbearing = _('NE')
			elif int(float(windbearing)) >= 45.00 and int(float(windbearing)) < 67.50:
				windbearing = _('EN')
			elif int(float(windbearing)) >= 67.50 and int(float(windbearing)) < 112.50:
				windbearing = _('E')
			elif int(float(windbearing)) >= 112.50 and int(float(windbearing)) < 135.00:
				windbearing = _('ES')
			elif int(float(windbearing)) >= 135.00 and int(float(windbearing)) < 157.50:
				windbearing = _('SE')
			elif int(float(windbearing)) >= 157.50 and int(float(windbearing)) < 202.50:
				windbearing = _('S')
			elif int(float(windbearing)) >= 202.50 and int(float(windbearing)) < 225.00:
				windbearing = _('SW')
			elif int(float(windbearing)) >= 225.00 and int(float(windbearing)) < 247.50:
				windbearing = _('WS')
			elif int(float(windbearing)) >= 247.50 and int(float(windbearing)) < 270.00:
				windbearing = _('W')
			elif int(float(windbearing)) >= 270.00 and int(float(windbearing)) < 315.00:
				windbearing = _('WN')
			elif int(float(windbearing)) >= 315.00 and int(float(windbearing)) < 337.50:
				windbearing = _('NW')
			elif int(float(windbearing)) >= 337.50 and int(float(windbearing)) < 360.00:
				windbearing = _('N')
			else:
				windbearing = ''
		except:
			windbearing = ''
		print_dbg('--- getFav2Page-windbearing --->', windbearing) #DBG
		Wind = re.findall('WIND_SPEED","value":(.*?)}', info)
		try:
			wind = Wind[0].strip()
			wind1 = Wind[0].strip().split('.')[0]
			wind2 = Wind[0].strip().split('.')[1]
			if int(wind2[0]) >= 5:
				wind = int(float(wind))
				wind += 1
			else:
				wind = wind1
			print_dbg('--- getFav2Page-windspeedunits.value --->', config.plugins.airly.windspeedunits.value) #DBG
			if config.plugins.airly.windspeedunits.value == 'km':
				self['wind'].text = str(wind) + self.windkmunits + ' ( ' + str(windbearing) + ' )'
			elif config.plugins.airly.windspeedunits.value == 'm':
				wind = wind * 1000/3600
				self['wind'].text = str(wind) + self.windmunits + ' ( ' + str(windbearing) + ' )'
			self['Wind'].show()
		except:
			wind = ''
			self['wind'].text = ''
			self['Wind'].hide()
		print_dbg('--- getFav2Page-wind --->', wind) #DBG
		MeasurementTime = re.findall('tillDateTime":"(.*?)"', info)
		try:
			MeasurementTime = MeasurementTime[0].replace("T", " ").split('.')[0]
			TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
			utc = datetime.datetime.utcnow()
			utc = datetime.datetime.utcnow().strftime(MeasurementTime)
			timestamp = calendar.timegm((datetime.datetime.strptime(utc, TIME_FORMAT)).timetuple())
			local = datetime.datetime.fromtimestamp(timestamp).strftime(TIME_FORMAT)
			measurementtime = str(local)
			self['measurementtime'].text = str(local)
		except:
			measurementtime = ''
			self['measurementtime'].text = ''
		print_dbg('--- getFav2Page-measurementtime --->', measurementtime) #DBG		
		try:
			if config.plugins.airly.fav2modeid.value:
				SeID = re.findall('"id":(.*?),"location', info)
				seid = SeID[0].strip()
				self['seid'].text = str(seid)
			else:
				seid = ''
				self['seid'].text = (_('Interpolated measurement'))
			self['SeID'].show()
		except:
			seid = ''
			self['seid'].text = ''
			self['SeID'].hide()
		print_dbg('--- getFav2Page-seid --->', str(seid)) #DBG
		NO2 = re.findall('NO2","value":(.*?)}', info)
		self['NO2'].text = 'NO' + self.sub2 + ':'
		try:
			no2 = NO2[0].strip()
			no21 = NO2[0].strip().split('.')[0]
			no22 = NO2[0].strip().split('.')[1]
			if int(no22[0]) >= 5:
				no2 = int(float(no2))
				no2 += 1
			else:
				no2 = no21
			no2 = str(no2) + self.pmunits
			self['no2'].text = no2
		except:
			no2 = ''
			self['no2'].text = ''
			self['NO2'].text = ''
		print_dbg('--- getFav2Page-NO2 --->', no2) #DBG
		O3 = re.findall('O3","value":(.*?)}', info)
		self['O3'].text = 'O' + self.sub3 + ':'
		try:
			o3 = O3[0].strip()
			o31 = O3[0].strip().split('.')[0]
			o32 = O3[0].strip().split('.')[1]
			if int(o32[0]) >= 5:
				o3 = int(float(o3))
				o3 += 1
			else:
				o3 = o31
			o3 = str(o3) + self.pmunits
			self['o3'].text = o3
		except:
			o3 = ''
			self['o3'].text = ''
			self['O3'].text = ''
		print_dbg('--- getFav2Page-O3 --->', o3) #DBG
		SO2 = re.findall('SO2","value":(.*?)}', info)
		self['SO2'].text = 'SO' + self.sub2 + ':'
		try:
			so2 = SO2[0].strip()
			so21 = SO2[0].strip().split('.')[0]
			so22 = SO2[0].strip().split('.')[1]
			if int(so22[0]) >= 5:
				so2 = int(float(so2))
				so2 += 1
			else:
				so2 = so21
			so2 = str(so2) + self.pmunits
			self['so2'].text = so2
		except:
			so2 = ''
			self['so2'].text = ''
			self['SO2'].text = ''
		print_dbg('--- getFav2Page-SO2 --->', so2) #DBG
		CO = re.findall('CO","value":(.*?)}', info)
		self['CO'].text = 'CO:'
		try:
			co = CO[0].strip()
			co1 = CO[0].strip().split('.')[0]
			co2 = CO[0].strip().split('.')[1]
			if int(co2[0]) >= 5:
				co = int(float(co))
				co += 1
			else:
				co = co1
			co = str(co) + self.pmunits
			self['co'].text = co
		except:
			co = ''
			self['co'].text = ''
			self['CO'].text = ''
		print_dbg('--- getFav2Page-CO --->', co) #DBG

		WNO2 = re.findall('pollutant":"NO2","limit":200.0,"percent":(.*?),"averaging', info)
		try:
			wno2 = WNO2[0].strip()
			wno21 = WNO2[0].strip().split('.')[0]
			wno22 = WNO2[0].strip().split('.')[1]
			if int(wno22[0]) >= 5:
				wno2 = int(float(wno2))
				wno2 += 1
			else:
				wno2 = wno21
			if int(wno2) > 100:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2high'].show()
			else:
				wno2 = str(wno2) + self.huunits
				self['wno2'].text = wno2
				self['wno2high'].text = wno2
				self['wno2'].show()
		except:
			wno2 = ''
			self['wno2'].text = ''
			self['wno2high'].text = ''
		print_dbg('--- getFav2Page-WNO2 --->', wno2) #DBG
		WO3 = re.findall('pollutant":"O3","limit":100.0,"percent":(.*?),"averaging', info)
		try:
			wo3 = WO3[0].strip()
			wo31 = WO3[0].strip().split('.')[0]
			wo32 = WO3[0].strip().split('.')[1]
			if int(wo32[0]) >= 5:
				wo3 = int(float(wo3))
				wo3 += 1
			else:
				wo3 = wo31
			if int(wo3) > 100:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3high'].show()
			else:
				wo3 = str(wo3) + self.huunits
				self['wo3'].text = wo3
				self['wo3high'].text = wo3
				self['wo3'].show()
		except:
			wo3 = ''
			self['wo3'].text = ''
			self['wo3high'].text = ''
		print_dbg('--- getFav2Page-WO3 --->', wo3) #DBG
		WSO2 = re.findall('pollutant":"SO2","limit":350.0,"percent":(.*?),"averaging', info)
		try:
			wso2 = WSO2[0].strip()
			wso21 = WSO2[0].strip().split('.')[0]
			wso22 = WSO2[0].strip().split('.')[1]
			if int(wso22[0]) >= 5:
				wso2 = int(float(wso2))
				wso2 += 1
			else:
				wso2 = wso21
			if int(wso2) > 100:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2high'].show()
			else:
				wso2 = str(wso2) + self.huunits
				self['wso2'].text = wso2
				self['wso2high'].text = wso2
				self['wso2'].show()
		except:
			wso2 = ''
			self['wso2'].text = ''
			self['wso2high'].text = ''
		print_dbg('--- getFav2Page-WSO2 --->', wso2) #DBG
		WCO = re.findall('pollutant":"CO","limit":30000.0,"percent":(.*?),"averaging', info)
		try:
			wco = WCO[0].strip()
			wco1 = WCO[0].strip().split('.')[0]
			wco2 = WCO[0].strip().split('.')[1]
			if int(wco2[0]) >= 5:
				wco = int(float(wco))
				wco += 1
			else:
				wco = wco1
			if int(wco) > 100:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wcohigh'].show()
			else:
				wco = str(wco) + self.huunits
				self['wco'].text = wco
				self['wcohigh'].text = wco
				self['wco'].show()
		except:
			wco = ''
			self['wco'].text = ''
			self['wcohigh'].text = ''
		print_dbg('--- getFav2Page-WCO --->', wco) #DBG
		
		if no2 or o3 or so2 or co:
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['GasTitle'].text = (_('Gas concentration levels'))
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = (_("Gas standards we use in Airly:\n\n* NO%s - 200%s - hourly average\n* O%s - 100%s - eight-hour average\n* SO%s - 350%s - hourly average\n* CO - 30 mg%s - hourly average.") % (self.sub2, self.pmunits, self.sub3, self.pmunits, self.sub2,  self.pmunits, self.pmunits2))
		else:
			self['GasTitle'].text = ''
			self.loadPNG('pm25png', PLUGIN_PATH + '/gfx/other/pm25.png')
			self.loadPNG('pm10png', PLUGIN_PATH + '/gfx/other/pm10.png')
			self.loadPNG('pm1png', PLUGIN_PATH + '/gfx/other/pm1.png')
			self.loadPNG('caqipng', PLUGIN_PATH + '/gfx/other/caqi.png')
			self['caqibarpng'].show()
			self['description1'].text = (_("PM2.5 is an air pollution with a diameter of 2.5 micrometers (one thousandth millimeter) or less. These particles remain suspended in the air and do not disperse. Limit = 25.0")) + self.pmunits + "."
			self['description2'].text = (_("PM10 is 10 micrometers (one thousandth millimeter) in diameter. Particles of this size (PM10 or less) can penetrate the deepest parts of the lungs due to their small size. Limit = 50.0")) + self.pmunits + "."
			self['description3'].text = (_("PM1 are ultra-fine particles with an aerodynamic diameter of less than 0.1 micrometers. Ultra-fine dust is the most destructive variant of fine particles, as they penetrate the lungs directly into the bloodstream and spread into organs."))
			self['description4'].text = (_("CAQI is an indicator of hourly air quality. Its value tells you how clean or polluted the air is and how breathing such air affects health. The European scale (CAQI) consists of values from 0 to 100. The higher the value of the indicator, the greater the risk of negative health symptoms and bad mood."))

		if pollutionlevel == 'VERY_LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/1.png')
			self['ldesc'].text = (_('The perfect day for outdoor activity.'))
		elif pollutionlevel == 'LOW':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/2.png')
			self['ldesc'].text = (_('Good air. You can go outside and enjoy the day.'))
		elif pollutionlevel == 'MEDIUM':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/3.png')
			self['ldesc'].text = (_('It was better. This is not the best day for outside activity.'))
		elif pollutionlevel == 'HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/4.png')
			self['ldesc'].text = (_('Poor air quality. It is better to stay at home today.'))
		elif pollutionlevel == 'VERY_HIGH':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/5.png')
			self['ldesc'].text = (_('Very poor air quality. Protect your lungs.'))
		elif pollutionlevel == 'EXTREME':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/6.png')
			self['ldesc'].text = (_('Extremely bad air quality. Do not go out without a mask.'))
		elif pollutionlevel == 'AIRMAGEDDON':
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/7.png')
			self['ldesc'].text = (_('AIRMAGEDDON.\nDo not breathe...'))
		else:
			self.loadPNG('indexback', PLUGIN_PATH + '/gfx/indexbacks/0.png')
			self['airqualityindex'].text = ''
			self['CAQI'].hide()
			self['PM25'].hide()
			self['PM10'].hide()
			self['Temperature'].hide()
			self['Pressure'].hide()
			self['Humidity'].hide()
			self['Wind'].hide()
			self['SeID'].hide()
			self['pm25'].text = ''
			self['pm10'].text = ''
			self['pm1'].text = ''
			self['GasTitle'].text = ''
			self['NO2'].text = ''
			self['no2'].text = ''
			self['SO2'].text = ''
			self['so2'].text = ''
			self['O3'].text = ''
			self['o3'].text = ''
			self['CO'].text = ''
			self['co'].text = ''
			self['pm25png'].hide()
			self['pm10png'].hide()
			self['pm1png'].hide()
			self['caqipng'].hide()
			self['caqibarpng'].hide()
			self['description1'].text = ''
			self['description2'].text = ''
			self['description3'].text = ''
			self['description4'].text = ''
			self['wpm25'].text = ''
			self['wpm10'].text = ''
			self['wpm25high'].text = ''
			self['wpm10high'].text = ''
			self['wno2'].text = ''
			self['wo3'].text = ''
			self['wso2'].text = ''
			self['wco'].text = ''
			self['wno2high'].text = ''
			self['wo3high'].text = ''
			self['wso2high'].text = ''
			self['wcohigh'].text = ''
			self['temperature'].text = ''
			self['pressure'].text = ''
			self['humidity'].text = ''
			self['wind'].text = ''
			self['seid'].text = ''
			self['city'].text = _('Airly')
			self['street'].text = '1.0-r46'
			if api_connection == True:
				if self.apicheck == False:
					if self.apirate == True:
						self['ldesc'].text = (_('API key limit exceeded.'))
						self['ldesc1'].text = (_('Minute limit: 50\nDaily limit: 100'))
						self['ldesc2'].text = (_('The daily limit is reduced every day at midnight, the minute limit every full minute.'))
						self['ldesc3'].text = ''
					else:
						self['ldesc'].text = (_('There are no data or no sensors in this location yet, but they may soon appear!'))
						self['ldesc1'].text = (_('Go to WiemCzymOddycham.pl'))
						self['ldesc2'].text = (_('Report or vote for the town you choose to receive the sensor.\nEncourage family and friends to cast their votes for a specific location!'))
						self['ldesc3'].text = (_('Check what you are breathing!'))
				else:
					self['ldesc'].text = (_('No API token !!!'))
					self['ldesc1'].text = (_('Go to https://developer.airly.org/login'))
					self['ldesc2'].text = (_('Register and get a free API token.\nCopy it and place it in the file\n/etc/enigma2/Airly/api.txt'))
					self['ldesc3'].text = (_('Close and reopen Airly!'))
			else:
				self['ldesc'].text = (_('Airly API server connection error!'))
				self['ldesc1'].text = (_('Either Airly server or ...'))
				self['ldesc2'].text = (_('... your internet connection is down.'))
				self['ldesc3'].text = ''
			self['ldesc1'].show()
			self['ldesc2'].show()
			self['ldesc3'].show()
		return

	def config(self):
		print_dbg('--- AirlyPreview --->', 'goto AirlyConfig') #DBG
		self.session.open(AirlyConfig)
		
	def histogram(self):
		global lforecastidx, lforecastcolidx, lhistoryidx, lhistorycolidx, lhistorytempidx, lhistorytempcolidx, lhistorypresidx, lhistorytimeidx, lhistorytemptimeidx, lhistoryprestimeidx
		print_dbg('--- histogram --->', 'started') #DBG
		if os.path.exists("/tmp/Airly/airly.out"):
			f = open("/tmp/Airly/airly.out", "r+")
			info_out = f.read()
			his_startpos = info_out.find('history')
			his_endpos = info_out.find('forecast')
			history = info_out[his_startpos:his_endpos]
			for_startpos = info_out.find('forecast')
			for_endpos = info_out.find('}]}]}')
			forecast = info_out[for_startpos:for_endpos]
			f.close()
		else:
			forecast = ''
			history = ''

		print_dbg('--- histogram-info_out --->', info_out) #DBG
		print_dbg('--- histogram-history --->', history) #DBG
		print_dbg('--- histogram-forecast --->', forecast) #DBG

		lforecastidx = []
		lforecastcolidx = []
		lhistoryidx = []
		lhistorycolidx = []
		lhistorytempidx = []
		lhistorytempcolidx = []
		lhistorypresidx = []
		lforecasttimeidx = []
		lhistorytimeidx = []
		lhistorytemptimeidx = []
		lhistoryprestimeidx = []
		forecast = forecast.split('fromDateTime')
		history = history.split('fromDateTime')
		
		offset = timezone if (localtime().tm_isdst == 0) else altzone
		offset = offset / -3600

		if len(forecast) >= 24:
			for x in (1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24):
				try:
					tmp = re.findall('name":"AIRLY_CAQI","value":(.*?),', forecast[x])
					if tmp[0] != 'null':
						lforecastidx.append(tmp[0].split('.')[0])
					else:
						lforecastidx.append(tmp[0].replace('null', '0'))
				except IndexError:
					lforecastidx.append('0')

				try:
					tmp = re.findall('color":"(.*?)"', forecast[x])
					lforecastcolidx.append(tmp[0])
				except IndexError:
					lforecastcolidx.append('#FFFFFF')
		print_dbg('--- histogram-lforecastidx --->', lforecastidx) #DBG
		print_dbg('--- histogram-lforecastcolidx --->', lforecastcolidx) #DBG

		if len(history) >= 24:
			for x in (1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24):
				try:
					tmp = re.findall('tillDateTime.*T(.*?):00.*Z', history[x])
					if tmp[0] != 'null':
						lhistorytimeidx.append(str(int(tmp[0]) + offset))
						for (i, item) in enumerate(lhistorytimeidx):
							if item == '25':
								lhistorytimeidx[i] = '1'
					else:
						lhistorytimeidx.append(tmp[0].replace('null', '0'))
				except IndexError:
					lhistorytimeidx.append('0')

				try:
					tmp = re.findall('name":"AIRLY_CAQI","value":(.*?),', history[x])
					if tmp[0] != 'null':
						lhistoryidx.append(tmp[0].split('.')[0])
					else:
						lhistoryidx.append(tmp[0].replace('null', '0'))
				except IndexError:
					lhistoryidx.append('0.00')
					
				try:
					tmp = re.findall('color":"(.*?)"', history[x])
					lhistorycolidx.append(tmp[0])
				except IndexError:
					lhistorycolidx.append('#FFFFFF')

				try:
					tmp = re.findall('name":"TEMPERATURE","value":(.*?)},{"name"', history[x])
					lhistorytempidx.append(tmp[0])
				except IndexError:
					lhistorytempidx.append('0.0')
				lhistorytempidx = [str(round(float(i))).split('.')[0].replace('-0', '0') for i in lhistorytempidx]
				lhistorytempcolidx = lhistorytempidx[:]
				for n, i in enumerate(lhistorytempcolidx):
					if int(i) >= -40 and int(i) < -30:
						lhistorytempcolidx[n] = "#0184B6"
					elif int(i) >= -30 and int(i) < -20:
						lhistorytempcolidx[n] = "#5FBCC9"
					elif int(i) >= -20 and int(i) < -15:
						lhistorytempcolidx[n] = "#9BDBDB"
					elif int(i) >= -15 and int(i) < -10:
						lhistorytempcolidx[n] = "#BAE5DF"
					elif int(i) >= -10 and int(i) < -5:
						lhistorytempcolidx[n] = "#DEF0E9"
					elif int(i) >= -5 and int(i) < 5:
						lhistorytempcolidx[n] = "#FFFFFF"
					elif int(i) >= 5 and int(i) < 10:
						lhistorytempcolidx[n] = "#F3F0DA"
					elif int(i) >= 10 and int(i) < 15:
						lhistorytempcolidx[n] = "#F3F0A7"
					elif int(i) >= 15 and int(i) < 20:
						lhistorytempcolidx[n] = "#F6E986"
					elif int(i) >= 20 and int(i) < 30:
						lhistorytempcolidx[n] = "#FDCF58"
					elif int(i) >= 30 and int(i) < 40:
						lhistorytempcolidx[n] = "#FF7F36"
					elif int(i) >= 40 and int(i) < 50:
						lhistorytempcolidx[n] = "#FD3827"
				lhistorytemptimeidx = lhistorytimeidx[:]
				lhistorytemptimeidx = [str(i).split(':')[0] for i in lhistorytemptimeidx]

				try:
					tmp = re.findall('name":"PRESSURE","value":(.*?)},{', history[x])
					lhistorypresidx.append(tmp[0])
				except IndexError:
					lhistorypresidx.append('0.0')
				lhistorypresidx = [str(round(float(i))).split('.')[0] for i in lhistorypresidx]
		lhistorypresidx_half = lhistorypresidx[len(lhistorypresidx)/2:]
		print_dbg('--- histogram-lhistorypresidx_half --->', lhistorypresidx_half) #DBG
		lhistorypresidx = lhistorypresidx_half[:]
		lhistoryprestimeidx_half  = lhistorytimeidx[:]
		lhistoryprestimeidx = lhistoryprestimeidx_half[len(lhistoryprestimeidx_half)/2:]

		print_dbg('--- histogram-lhistoryidx --->', lhistoryidx) #DBG
		print_dbg('--- histogram-lhistorycolidx --->', lhistorycolidx) #DBG
		print_dbg('--- histogram-lhistorytempidx --->', lhistorytempidx) #DBG
		print_dbg('--- histogram-lhistorytempcolidx --->', lhistorytempcolidx) #DBG
		print_dbg('--- histogram-lhistorypresidx --->', lhistorypresidx) #DBG
		print_dbg('--- histogram-lhistorytimeidx --->', lhistorytimeidx) #DBG
		print_dbg('--- histogram-lhistorytemptimeidx --->', lhistorytemptimeidx) #DBG
		print_dbg('--- histogram-lhistoryprestimeidx --->', lhistoryprestimeidx) #DBG
		self.session.open(AirlyHistogram)

	def hideScreen(self):
		self.hideflag = _hideScreen(self.hideflag)

	def exit(self):
		print_dbg('-- AirlyPreview --->', 'Exit') #DBG
		if self.hideflag == False:
			self.hideflag = True
			writeAlpha('%i' % config.av.osd_alpha.value)
		if fileExists(DBG_FILE):
			with open(DBG_FILE) as f:
				newText = f.read()
				newText = re.sub('apikey\:\ [0-9a-z]+', 'apikey: hidden', newText)
				f.close()
			with open(DBG_FILE, "w") as f:
				f.write(newText)
				f.close()
		self.close()
		
	def createSummary(self):
		return AirlyLCD


class AirlyConfig(ConfigListScreen, Screen):
	skinFHD = """
		<screen name="AirlyConfigFHD" position="0,0" size="1920,1080" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Konfiguracja">
			<widget position="0,0" size="1920,1080" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1920,1080" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="384,48" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="20,0" size="112,45" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="180,0" size="200,45" source="tlogo" render="Label" font="AP_Regular; 20" foregroundColor="#18FFFFFF" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1792,0" size="128,48" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1792,0" size="128,48" source="global.CurrentTime" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,100" size="965,100" name="faqtitle" font="{font2};50" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="90,170" size="920,335" name="info" font="{font2};23" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="100,490" size="900,60" name="address" font="{font2};40" foregroundColor="#00BE4624" halign="center" transparent="1" zPosition="5" />
			<widget position="250,500" size="600,498" name="schpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1100,100" size="730,810" name="config" font="{font2};30" foregroundColor="#FFFFFF" itemHeight="45" enableWrapAround="1" scrollbarMode="showNever" transparent="1" zPosition="5" />
			<widget position="1120,950" size="30,30" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1260,950" size="30,30" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1150,953" size="150,30" source="key_red" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" valign="top" zPosition="5" />
			<widget position="1300,953" size="150,30" source="key_green" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" valign="top" zPosition="5" />
			<widget position="1680,950" size="60,30" name="textpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1750,950" size="60,30" name="helppng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="0,1032" size="384,48" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1536,1032" size="384,48" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="70,100" size="965,100" name="helptitle" font="{font2};50" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="120,170" size="910,330" name="label" font="AP_Val1;28" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="90,550" size="920,350" name="label2" font="{font2};28" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="5" />
			<widget position="110,170" size="30,30" name="help_red" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="110,207" size="30,30" name="help_green" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="110,244" size="30,30" name="help_yellow" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="110,281" size="30,30" name="help_blue" alphatest="blend" transparent="1" zPosition="5" />
		</screen>"""

	skin = """
		<screen name="AirlyConfig" position="0,0" size="1280,720" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Konfiguracja">
			<widget position="0,0" size="1280,720" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1280,720" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="250,31" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="10,2" size="49,25" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="65,0" size="160,31" source="tlogo" render="Label" font="AP_Regular; 16" foregroundColor="#1839A0DB" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1197,0" size="83,31" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1197,0" size="83,31" source="global.CurrentTime" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,70" size="610,30" name="faqtitle" font="{font2};26" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="80,110" size="590,350" name="info" font="{font2};14" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="80,315" size="590,30" name="address" font="{font2};26" foregroundColor="#00BE4624" halign="center" transparent="1" zPosition="5" />
			<widget position="175,330" size="400,332" name="schpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="740,80" size="480,525" name="config" font="{font2};20" foregroundColor="#FFFFFF" itemHeight="35" enableWrapAround="1" scrollbarMode="showNever" transparent="1" zPosition="5" />
			<widget position="750,630" size="20,20" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="850,630" size="20,20" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="770,631" size="150,30" source="key_red" render="Label" font="AP_Regular;16" foregroundColor="#FFFFFF" noWrap="1" transparent="1" valign="top" zPosition="5" />
			<widget position="870,631" size="195,30" source="key_green" render="Label" font="AP_Regular;16" foregroundColor="#FFFFFF" noWrap="1" transparent="1" valign="top" zPosition="5" />
			<widget position="1100,631" size="40,20" name="textpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1150,631" size="40,20" name="helppng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="0,689" size="250,31" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1030,689" size="250,31" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="70,70" size="610,30" name="helptitle" font="{font2};26" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="130,110" size="590,220" name="label" font="AP_Val1; 16" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="90,330" size="590,300" name="label2" font="{font2};16" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="5" />
			<widget position="120,110" size="20,20" name="help_red" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="120,130" size="20,20" name="help_green" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="120,150" size="20,20" name="help_yellow" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="120,170" size="20,20" name="help_blue" alphatest="blend" transparent="1" zPosition="5" />
		</screen>"""

	def __init__(self, session):
		writeAlpha('%i' % config.plugins.airly.transparency.value)
		self.version = '1.0-r46'
		print_dbg('++ AirlyConfig --->', 'Started') #DBG
		if config.plugins.airly.font.value == 'apf1':
			font2 = 'AP_Val_desc1'
		elif config.plugins.airly.font.value == 'apf2':
			font2 = 'AP_Val_desc2'
		else:
			font2 = 'AP_Val_desc3'
		self.dict = {'font2': font2}
		self.display_width = getDesktop(0).size().width()
		if self.display_width == 1920:
			self.skin = applySkinVars(AirlyConfig.skinFHD, self.dict)
		else:
			self.skin = applySkinVars(AirlyConfig.skin, self.dict)
		Screen.__init__(self, session)
		self.title = 'Airly - Konfiguracja'
		self.hideflag = True
		self.showhelp = False
		self['tlogo'] = StaticText(str(self.version))
		self['airlyback'] = Pixmap()
		self['infoback'] = Pixmap()
		self['header_l'] = Pixmap()
		self['footer_l'] = Pixmap()
		self['alogo'] = Pixmap()
		self['header_r'] = Pixmap()
		self['footer_r'] = Pixmap()
		self['schpng'] = Pixmap()
		self['redpng'] = Pixmap()
		self['greenpng'] = Pixmap()
		self['helppng'] = Pixmap()
		self['textpng'] = Pixmap()
		self['faqtitle'] = Label(_('I N F O R M A T I O N'))
		self['info'] = Label(_('To get the latitude and longitude of the location that you are interested in, visit the following page, select a place between the sensors and note the values of "lat" e.g. "50.05679" and "lng" e.g. "19.77265" found in the address bar. The second method is use the sensor number (ID), which you will also find at the end of address bar after the letter "i" e.g. "811". For the first method, for aesthetic reason, you should also manually enter the address because for the interpolated measurement API not provide one.\nAddress fields do not affect the displayed data.'))
		self['address'] = Label('https://airly.org/map/')
		self['helptitle'] = Label(_('H E L P'))
		self['help_red'] = Pixmap()
		self['help_green'] = Pixmap()
		self['help_yellow'] = Pixmap()
		self['help_blue'] = Pixmap()
		self['label'] = Label(_('   Exit / Return\n   Favorite Location 1 (Main) | Save Settings (Config)\n   Favorite location 2 (Main) | ID list (Config)\n   Default location (Main)\nHelp: Show / Hide Help Window\nRadio: Show / Hide Plugin\nOK: Show / Hide Histogram (Main)\nOK / TEXT: Virtual Keyboard (Config)\nUp / Down: ID list (Main)'))
		self['label2'] = Label(_('Author: Ampersand\n------------------------------------------\nThe available update is checked only when you enter the configuration.\n------------------------------------------\nSupport:\nzdzislaw22'))
		self.list = []
		self.setup_title = _('Settings')
		self.onChangedEntry = []
		ConfigListScreen.__init__(self, self.list, on_change = self.changedEntry)
		self['key_red'] = StaticText(_('Exit'))
		self['key_green'] = StaticText(_('Save'))
		self['actions'] = ActionMap(['AirlyConfigActions'], {
			'cancel': self.exit,
			'red': self.exit,
			'green': self.save,
			'hideScreen': self.hideScreen,
			'displayHelp': self.showHelp,
			'ok': self.KeyText,
			'showVirtualKeyboard': self.KeyText
			}, -2)
		self.runSetup()
		self.onLayoutFinish.append(self.onLayoutFinished)

	def onLayoutFinished(self):
		if config.plugins.airly.background.value == '1':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back1.png')
		elif config.plugins.airly.background.value == '2':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back2.png')
		elif config.plugins.airly.background.value == '3':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back3.png')
		elif config.plugins.airly.background.value == '4':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back4.png')
		elif config.plugins.airly.background.value == '5':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back5.png')
		elif config.plugins.airly.background.value == '6':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back6.png')
		self.loadPNG('infoback', PLUGIN_PATH + '/gfx/infoback.png')
		self.loadPNG('header_l', PLUGIN_PATH + '/gfx/header_l.png')
		self.loadPNG('footer_l', PLUGIN_PATH + '/gfx/footer_l.png')
		self.loadPNG('alogo', PLUGIN_PATH + '/gfx/alogo.png')
		self.loadPNG('header_r', PLUGIN_PATH + '/gfx/header_r.png')
		self.loadPNG('footer_r', PLUGIN_PATH + '/gfx/footer_r.png')
		if lang == 'pl':
			self.loadPNG('schpng', PLUGIN_PATH + '/gfx/other/sch_pl.png')
		elif lang == 'es':
			self.loadPNG('schpng', PLUGIN_PATH + '/gfx/other/sch_es.png')
		else:
			self.loadPNG('schpng', PLUGIN_PATH + '/gfx/other/sch_en.png')
		self.loadPNG('redpng', PLUGIN_PATH + '/gfx/buttons/red.png')
		self.loadPNG('greenpng', PLUGIN_PATH + '/gfx/buttons/green.png')
		self.loadPNG('helppng', PLUGIN_PATH + '/gfx/buttons/help.png')
		self.loadPNG('textpng', PLUGIN_PATH + '/gfx/buttons/text.png')
		self.loadPNG('help_red', PLUGIN_PATH + '/gfx/buttons/red.png')
		self.loadPNG('help_green', PLUGIN_PATH + '/gfx/buttons/green.png')
		self.loadPNG('help_yellow', PLUGIN_PATH + '/gfx/buttons/yellow.png')
		self.loadPNG('help_blue', PLUGIN_PATH + '/gfx/buttons/blue.png')
		self['helptitle'].hide()
		self['help_red'].hide()
		self['help_green'].hide()
		self['help_yellow'].hide()
		self['help_blue'].hide()
		self['label'].hide()
		self['label2'].hide()
		if config.plugins.airly.autocheck.value:
			self.link = 'http://e2support.i586.pl'
			self.makeVersionTimer = eTimer()
			self.makeVersionTimer.callback.append(self.download(self.link, self.checkVersion))
			self.makeVersionTimer.start(500, True)
		self.setTitle(self.title)
		return
		
	def loadPNG(self, object, png):
		if os.path.exists(png):
			self.picload = ePicLoad()
			self[object].instance.setPixmap(gPixmapPtr())
			scale = AVSwitch().getFramebufferScale()
			size = self[object].instance.size()
			self.picload.setPara((size.width(), size.height(), scale[0], scale[0], False, 1, "#FF000000"))
			if self.picload.startDecode(png, 0, 0, False) == 0:
				ptr = self.picload.getData()
				if ptr != None:
					self[object].instance.setPixmap(ptr)
					self[object].show()
			del self.picload

	def runSetup(self):
		self.list = []
		self.list.append(getConfigListEntry(_('ID (Home) instead of coordinates'), config.plugins.airly.hmodeid))
		if config.plugins.airly.hmodeid.value:
			self.list.append(getConfigListEntry(_('  ID (Home)'), config.plugins.airly.homeid))
		else:
			self.list.append(getConfigListEntry(_('  Latitude (Home)'), config.plugins.airly.homelat))
			self.list.append(getConfigListEntry(_('  Longitude (Home)'), config.plugins.airly.homelon))
			self.list.append(getConfigListEntry(_('  City (Home)'), config.plugins.airly.hcity))
			self.list.append(getConfigListEntry(_('  Street (Home)'), config.plugins.airly.hstreet))
			self.list.append(getConfigListEntry(_('  Country (Home)'), config.plugins.airly.hcountry))
		self.list.append(getConfigListEntry(_('ID (1) instead of coordinates'), config.plugins.airly.fav1modeid))
		if config.plugins.airly.fav1modeid.value:
			self.list.append(getConfigListEntry(_('  ID (1)'), config.plugins.airly.fav1id))
		else:
			self.list.append(getConfigListEntry(_('  Latitude (1)'), config.plugins.airly.fav1lat))
			self.list.append(getConfigListEntry(_('  Longitude (1)'), config.plugins.airly.fav1lon))
			self.list.append(getConfigListEntry(_('  City (1)'), config.plugins.airly.fav1city))
			self.list.append(getConfigListEntry(_('  Street (1)'), config.plugins.airly.fav1street))
			self.list.append(getConfigListEntry(_('  Country (1)'), config.plugins.airly.fav1country))
		self.list.append(getConfigListEntry(_('ID (2) instead of coordinates'), config.plugins.airly.fav2modeid))
		if config.plugins.airly.fav2modeid.value:
			self.list.append(getConfigListEntry(_('  ID (2)'), config.plugins.airly.fav2id))
		else:
			self.list.append(getConfigListEntry(_('  Latitude (2)'), config.plugins.airly.fav2lat))
			self.list.append(getConfigListEntry(_('  Longitude (2)'), config.plugins.airly.fav2lon))
			self.list.append(getConfigListEntry(_('  City (2)'), config.plugins.airly.fav2city))
			self.list.append(getConfigListEntry(_('  Street (2)'), config.plugins.airly.fav2street))
			self.list.append(getConfigListEntry(_('  Country (2)'), config.plugins.airly.fav2country))
		self.list.append(getConfigListEntry(_('Wind speed units'), config.plugins.airly.windspeedunits))
		self.list.append(getConfigListEntry(_('Background'), config.plugins.airly.background))
		self.list.append(getConfigListEntry(_('Font set'), config.plugins.airly.font))
		self.list.append(getConfigListEntry(_('City names instead of "Favorite"'), config.plugins.airly.citylabels))
		self.list.append(getConfigListEntry(_('Update'), config.plugins.airly.autocheck))
		self.list.append(getConfigListEntry(_('Data in infobar (Home)'), config.plugins.airly.scheduler))
		if config.plugins.airly.scheduler.value:
			self.list.append(getConfigListEntry(_('  Check the data every'), config.plugins.airly.schedulerfrequency))
		self.list.append(getConfigListEntry(_('Data waiting time (max)'), config.plugins.airly.ctimeout))
		self.list.append(getConfigListEntry(_('ID list'), config.plugins.airly.idlist))
		self.list.append(getConfigListEntry(_('Debug'), config.plugins.airly.logs))
		self["config"].list = self.list
		self["config"].l.setList(self.list)

	def KeyText(self):
		if isinstance(self["config"].getCurrent()[1], ConfigText):
			try:
				self.session.openWithCallback(self.VirtualKeyBoardCallback, VirtualKeyBoard, title = self["config"].getCurrent()[0], text = self["config"].getCurrent()[1].getValue())
			except:
				pass

	def VirtualKeyBoardCallback(self, callback = None):
		if callback is not None and len(callback):
			self["config"].getCurrent()[1].setValue(callback)
			self["config"].invalidate(self["config"].getCurrent())
		
	def keyLeft(self):
		if self.showhelp == True:
			self.showhelp = False
			self.showHelpOff()
		else:
			ConfigListScreen.keyLeft(self)
			self.runSetup()

	def keyRight(self):
		if self.showhelp == True:
			self.showhelp = False
			self.showHelpOff()
		else:
			ConfigListScreen.keyRight(self)
			self.runSetup()
			
	def showHelp(self):
		if self.showhelp == False:
			self.showhelp = True
			self.showHelpOn()
		else:
			self.showhelp = False
			self.showHelpOff()
		
	def showHelpOn(self):
			self['faqtitle'].hide()
			self['info'].hide()
			self['address'].hide()
			self['schpng'].hide()
			self['helptitle'].show()
			self['help_red'].show()
			self['help_green'].show()
			self['help_yellow'].show()
			self['help_blue'].show()
			self['label'].show()
			self['label2'].show()

	def showHelpOff(self):
			self['helptitle'].hide()
			self['help_red'].hide()
			self['help_green'].hide()
			self['help_yellow'].hide()
			self['help_blue'].hide()
			self['label'].hide()
			self['label2'].hide()
			self['faqtitle'].show()
			self['info'].show()
			self['address'].show()
			self['schpng'].show()

	def save(self):
		print_dbg('-- Airly Config --->', 'save') #DBG
		for x in self["config"].list:
			x[1].save()
		# if config.plugins.airly.scheduler.value:
			# self.addSchedulerForInfobar()
		# else:
			# self.remSchedulerForInfobar()
		self.close()
		
	def hideScreen(self):
		self.hideflag = _hideScreen(self.hideflag)
				
	def checkVersion(self, output):
		self.pluginname = 'Airly'
		version = search('<img alt="Airly (.*?)"', output)
		if version is not None:
			version = version.group(1)
			print_dbg('--- checkVersion - version --->', str(version)) #DBG
			if version != self.version and int(version[5:7]) > int(self.version[5:7]):
				pluginsource = search('<a href="(.*?)"><img alt="Airly ', output)
				print_dbg('--- checkVersion - pluginsource --->', pluginsource.group(1)) #DBG
				if pluginsource is not None:
					self.pluginsource = pluginsource.group(1)
					self.pluginfile = self.pluginsource.replace('http://e2support.i586.pl/ccount-manager/click.php?id=airly', 'airly.ipk')
					print_dbg('--- checkVersion - self.pluginfile --->', self.pluginfile) #DBG
					versioninfo = re.findall('&#9734; (.*?)<br>', output)
					print_dbg('--- checkVersion - versioninfo --->', versioninfo)
					if len(versioninfo) > 0:
						info = ''
						idx = 0
						for x in versioninfo:
							idx += 1

						for i in range(idx):
							try:
								info = info + ' - ' + versioninfo[i] + '\n'
							except IndexError:
								Info = ''
						self.session.openWithCallback(self.downloadPlugin, MessageBox, _("\nUpdate available! %s version %s:\n\n%s\n-------------------------------------------\nDo you want to install it now?") % (self.pluginname, version, info), MessageBox.TYPE_YESNO)
					else:
						self.session.openWithCallback(self.downloadPlugin, MessageBox, _("\nUpdate available! %s version %s:\n-------------------------------------------\nDo you want to install it now?") % (self.pluginname, version), MessageBox.TYPE_YESNO)
		return

	def downloadPlugin(self, answer):
		if answer is True:
			self.pluginfile = '/tmp/Airly/' + self.pluginfile
			self.session.openWithCallback(self.close, DownloadUpdate, self.pluginsource, self.pluginfile, self.pluginname)

	def download(self, link, name):
		getPage(link).addCallback(name).addErrback(self.downloadError)

	def downloadError(self, output):
		pass

	def exit(self):
		print_dbg('-- AirlyConfig --->', 'Exit') #DBG
		if self.showhelp == True:
			self.showhelp = False
			self.showHelpOff()
		else:
			if self.hideflag == False:
				self.hideflag = True
				writeAlpha('%i' % config.av.osd_alpha.value)
				self.close()
			else:
				self.close()

	# for summary:
	def changedEntry(self):
		for x in self.onChangedEntry:
			x()

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())
		
	def createSummary(self):
		from Screens.Setup import SetupSummary
		return SetupSummary
		

class AirlyHistogram(Screen):
	skinFHDpart1 = """
		<screen name="AirlyHistogramFHD" position="0,0" size="1920,1080" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Histogram">
			<widget position="0,0" size="1920,1080" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1920,1080" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="384,48" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="20,0" size="112,45" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="180,0" size="200,45" source="tlogo" render="Label" font="AP_Regular; 20" foregroundColor="#18FFFFFF" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1792,0" size="128,48" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1792,0" size="128,48" source="global.CurrentTime" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="130,120" size="845,80" source="city" render="Label" font="AP_Title; 60" foregroundColor="#00db9326" noWrap="1" transparent="1" zPosition="5" />
			<widget position="130,180" size="840,50" source="htitle" render="Label" font="{font2};40" foregroundColor="#FFFFFF" halign="right" transparent="1" zPosition="5" />
			<widget position="130,630" size="840,50" source="ftitle" render="Label" font="{font2};40" foregroundColor="#FFFFFF" halign="right" transparent="1" zPosition="5" />
			<widget position="1120,180" size="648,50" source="ttitle" render="Label" font="{font2};40" foregroundColor="#FFFFFF" halign="right" transparent="1" zPosition="5" />
			<widget position="1120,630" size="648,50" source="ptitle" render="Label" font="{font2};40" foregroundColor="#FFFFFF" halign="right" transparent="1" zPosition="5" />"""
	FHDhistory1 = ''
	x = 130
	for i in range(24):
		FHDhistory1 += "<widget name=\"hprogress%d\" position=\"%d,250\" size=\"35,200\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDhistory2 = ''
	x = 130
	for i in range(24):
		FHDhistory2 += "<widget name=\"hisval%d\" position=\"%d,470\" size=\"35,40\" font=\"AP_Regular;18\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDhistory3 = ''
	x = 130
	for i in range(24):
		FHDhistory3 += "<widget name=\"histimeval%d\" position=\"%d,235\" size=\"35,20\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDforecast1 = ''
	x = 130
	for i in range(24):
		FHDforecast1 += "<widget name=\"fprogress%d\" position=\"%d,700\" size=\"35,200\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDforecast2 = ''
	x = 130
	for i in range(24):
		FHDforecast2 += "<widget name=\"forval%d\" position=\"%d,920\" size=\"35,40\" font=\"AP_Regular;18\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDforecast3 = ''
	x = 130
	for i in range(24):
		FHDforecast3 += "<widget name=\"fortimeval%d\" position=\"%d,685\" size=\"35,20\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 35
	FHDtemperature1 = ''
	x = 1120
	for i in range(24):
		FHDtemperature1 += "<widget name=\"tposprogress%d\" position=\"%d,250\" size=\"27,100\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 27
	FHDtemperature2 = ''
	x = 1120
	for i in range(24):
		FHDtemperature2 += "<widget name=\"tnegprogress%d\" position=\"%d,350\" size=\"27,100\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orTopToBottom\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 27
	FHDtemperature3 = ''
	x = 1120
	for i in range(24):
		FHDtemperature3 += "<widget name=\"tempval%d\" position=\"%d,470\" size=\"27,40\" font=\"AP_Regular;18\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 27
	FHDtemperature4 = ''
	x = 1120
	for i in range(24):
		FHDtemperature4 += "<widget name=\"temptimeval%d\" position=\"%d,235\" size=\"27,20\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 27
	FHDpressure1 = ''
	x = 1120
	for i in range(12):
		FHDpressure1 += "<widget name=\"pprogress%d\" position=\"%d,700\" size=\"54,200\" borderColor=\"#404040\" foregroundColor=\"#FFFFFF\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 54
	FHDpressure2 = ''
	x = 1120
	for i in range(12):
		FHDpressure2 += "<widget name=\"preval%d\" position=\"%d,920\" size=\"54,40\" font=\"AP_Regular;18\" foregroundColor=\"#FFFFFF\" halign=\"center\" noWrap=\"1\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 54
	FHDpressure3 = ''
	x = 1120
	for i in range(12):
		FHDpressure3 += "<widget name=\"pretimeval%d\" position=\"%d,685\" size=\"54,20\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" noWrap=\"1\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 54
	skinFHDpart2 = """
			<widget position="980,470" size="200,40" source="caqi" render="Label" font="AP_SansIt;18" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="980,240" size="50,20" source="hlmax" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="980,440" size="50,20" source="hlmin" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="980,920" size="200,40" source="caqi" render="Label" font="AP_SansIt;18" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="980,690" size="50,20" source="flmax" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="980,890" size="50,20" source="flmin" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1780,470" size="200,40" source="tempunits" render="Label" font="AP_SansIt;18" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1780,240" size="50,20" source="tlmax" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1780,340" size="50,20" source="tl0" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1780,440" size="50,20" source="tlmin" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1780,920" size="200,40" source="preunits" render="Label" font="AP_SansIt;18" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1780,690" size="50,20" source="plmax" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1780,890" size="50,20" source="plmin" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="0,1032" size="384,48" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1536,1032" size="384,48" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
		</screen>"""
	###---
	skinHDpart1 = """
		<screen name="AirlyHistogram" position="0,0" size="1280,720" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Prognoza">
			<widget position="0,0" size="1280,720" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1280,720" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="250,31" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="10,2" size="49,25" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="65,0" size="160,31" source="tlogo" render="Label" font="AP_Regular; 16" foregroundColor="#1839A0DB" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1197,0" size="83,31" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1197,0" size="83,31" source="global.CurrentTime" render="Label" font="AP_Regular;18" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,80" size="610,80" source="city" render="Label" font="AP_Title; 40" foregroundColor="#00db9326" noWrap="1" transparent="1" zPosition="5" />
			<widget position="70,120" size="576,30" source="htitle" render="Label" font="{font2};26" halign="right" transparent="1" zPosition="5" />
			<widget position="70,410" size="576,30" source="ftitle" render="Label" font="{font2};26" halign="right" transparent="1" zPosition="5" />
			<widget position="750,120" size="432,30" source="ttitle" render="Label" font="{font2};26" halign="right" transparent="1" zPosition="5" />
			<widget position="750,410" size="432,30" source="ptitle" render="Label" font="{font2};26" halign="right" transparent="1" zPosition="5" />"""
	HDhistory1 = ''
	x = 70
	for i in range(24):
		HDhistory1 += "<widget name=\"hprogress%d\" position=\"%d,160\" size=\"24,150\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDhistory2 = ''
	x = 70
	for i in range(24):
		HDhistory2 += "<widget name=\"hisval%d\" position=\"%d,330\" size=\"24,40\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDhistory3 = ''
	x = 70
	for i in range(24):
		HDhistory3 += "<widget name=\"histimeval%d\" position=\"%d,150\" size=\"24,20\" font=\"AP_Regular;8\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDforecast1 = ''
	x = 70
	for i in range(24):
		HDforecast1 += "<widget name=\"fprogress%d\" position=\"%d,450\" size=\"24,150\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDforecast2 = ''
	x = 70
	for i in range(24):
		HDforecast2 += "<widget name=\"forval%d\" position=\"%d,620\" size=\"24,40\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDforecast3 = ''
	x = 70
	for i in range(24):
		HDforecast3 += "<widget name=\"fortimeval%d\" position=\"%d,440\" size=\"24,20\" font=\"AP_Regular;8\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 24
	HDtemperature1 = ''
	x = 750
	for i in range(24):
		HDtemperature1 += "<widget name=\"tposprogress%d\" position=\"%d,160\" size=\"18,75\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 18
	HDtemperature2 = ''
	x = 750
	for i in range(24):
		HDtemperature2 += "<widget name=\"tnegprogress%d\" position=\"%d,235\" size=\"18,75\" borderColor=\"#404040\" borderWidth=\"1\" orientation=\"orTopToBottom\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 18
	HDtemperature3 = ''
	x = 750
	for i in range(24):
		HDtemperature3 += "<widget name=\"tempval%d\" position=\"%d,330\" size=\"18,40\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 18
	HDtemperature4 = ''
	x = 750
	for i in range(24):
		HDtemperature4 += "<widget name=\"temptimeval%d\" position=\"%d,150\" size=\"18,20\" font=\"AP_Regular;8\" foregroundColor=\"#FFFFFF\" halign=\"center\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 18
	HDpressure1 = ''
	x = 750
	for i in range(12):
		HDpressure1 += "<widget name=\"pprogress%d\" position=\"%d,450\" size=\"36,150\" borderColor=\"#404040\" foregroundColor=\"#FFFFFF\" borderWidth=\"1\" orientation=\"orBottomToTop\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 36
	HDpressure2 = ''
	x = 750
	for i in range(12):
		HDpressure2 += "<widget name=\"preval%d\" position=\"%d,620\" size=\"36,40\" font=\"AP_Regular;12\" foregroundColor=\"#FFFFFF\" halign=\"center\" noWrap=\"1\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 36
	HDpressure3 = ''
	x = 750
	for i in range(12):
		HDpressure3 += "<widget name=\"pretimeval%d\" position=\"%d,440\" size=\"36,20\" font=\"AP_Regular;8\" foregroundColor=\"#FFFFFF\" halign=\"center\" noWrap=\"1\" transparent=\"1\" zPosition=\"5\" />\n" % (i, x)
		x += 36
	skinHDpart2 = """
			<widget position="655,330" size="200,30" source="caqi" render="Label" font="AP_SansIt;12" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="660,155" size="50,20" source="hlmax" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="660,305" size="50,20" source="hlmin" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="650,620" size="200,30" source="caqi" render="Label" font="AP_SansIt;12" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="660,445" size="50,20" source="flmax" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="660,595" size="50,20" source="flmin" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1190,330" size="200,30" source="tempunits" render="Label" font="AP_SansIt;12" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1200,155" size="50,20" source="tlmax" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1200,230" size="50,20" source="tl0" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1200,305" size="50,20" source="tlmin" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1190,620" size="200,30" source="preunits" render="Label" font="AP_SansIt;12" foregroundColor="#FFFFFF" transparent="1" zPosition="5" />
			<widget position="1190,445" size="50,20" source="plmax" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="1190,595" size="50,20" source="plmin" render="Label" font="AP_Regular;12" foregroundColor="#FFFFFF" noWrap="1" transparent="1" zPosition="5" />
			<widget position="0,689" size="250,31" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1030,689" size="250,31" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
		</screen>"""
		
	def __init__(self, session):
		print_dbg('++ AirlyHistogram --->', 'Started') #DBG
		writeAlpha('%i' % config.plugins.airly.transparency.value)
		self.version = '1.0-r46'
		self.history = lhistoryidx
		self.hcol = lhistorycolidx
		self.forecast = lforecastidx
		self.fcol = lforecastcolidx
		self.temperature = lhistorytempidx
		self.tcol = lhistorytempcolidx
		self.pressure = lhistorypresidx
		self.historytime = lhistorytimeidx
		self.temptime = lhistorytemptimeidx
		self.pretime = lhistoryprestimeidx
		if config.plugins.airly.font.value == 'apf1':
			font2 = 'AP_Val_desc1'
		elif config.plugins.airly.font.value == 'apf2':
			font2 = 'AP_Val_desc2'
		else:
			font2 = 'AP_Val_desc3'
		self.dict = {'font2': font2}
		self.display_width = getDesktop(0).size().width()
		if self.display_width == 1920:
			self.skin = applySkinVars(AirlyHistogram.skinFHDpart1 + AirlyHistogram.FHDhistory1 + AirlyHistogram.FHDhistory2 + AirlyHistogram.FHDhistory3 + AirlyHistogram.FHDforecast1 + AirlyHistogram.FHDforecast2 + AirlyHistogram.FHDforecast3 + AirlyHistogram.FHDtemperature1 + AirlyHistogram.FHDtemperature2 + AirlyHistogram.FHDtemperature3 + AirlyHistogram.FHDtemperature4 + AirlyHistogram.FHDpressure1 + AirlyHistogram.FHDpressure2 + AirlyHistogram.FHDpressure3 + AirlyHistogram.skinFHDpart2, self.dict)
		else:
			self.skin = applySkinVars(AirlyHistogram.skinHDpart1 + AirlyHistogram.HDhistory1 + AirlyHistogram.HDhistory2 + AirlyHistogram.HDhistory3 + AirlyHistogram.HDforecast1 + AirlyHistogram.HDforecast2 + AirlyHistogram.HDforecast3 + AirlyHistogram.HDtemperature1 + AirlyHistogram.HDtemperature2 + AirlyHistogram.HDtemperature3 + AirlyHistogram.HDtemperature4 + AirlyHistogram.HDpressure1 + AirlyHistogram.HDpressure2 + AirlyHistogram.HDpressure3 + AirlyHistogram.skinHDpart2, self.dict)
		Screen.__init__(self, session)
		self.title = 'Airly - Histogram'
		self.hideflag = True
		self['tlogo'] = StaticText(str(self.version))
		self['airlyback'] = Pixmap()
		self['infoback'] = Pixmap()
		self['header_l'] = Pixmap()
		self['footer_l'] = Pixmap()
		self['alogo'] = Pixmap()
		self['header_r'] = Pixmap()
		self['footer_r'] = Pixmap()
		self['redpng'] = Pixmap()
		self['ftitle'] = StaticText(_('FORECAST   +24h'))
		self['htitle'] = StaticText(_('HISTORY   -24h'))
		self['ttitle'] = StaticText(_('TEMPERATURE   -24h'))
		self['tempunits'] = StaticText(_('°C'))
		self['ptitle'] = StaticText(_('PRESSURE   -12h'))
		self['preunits'] = StaticText(_('hPa'))
		self['caqi'] = StaticText(_('CAQI'))
		self.setup_title = _('Histogram')
		if AirlyPreview.currPlace == 0:
			self['city'] = StaticText(_(Home))
		elif AirlyPreview.currPlace == 1:
			self['city'] = StaticText(_(Favourite1))
		elif AirlyPreview.currPlace == 2:
			self['city'] = StaticText(_(Favourite2))
		self['key_red'] = StaticText(_('Exit'))
		self['actions'] = ActionMap(['AirlyHistogramActions'], {
			'cancel': self.exit,
			'red': self.exit,
			'ok': self.exit,
			'hideScreen': self.hideScreen
			}, -2)
		
		if len(self.history) < 24:
			for x in range(24 - len(self.history)):
				 self.history.append('0')
		print_dbg('--- Histogram-history --->', self.history) #DBG
		print_dbg('--- Histogram-history-len --->', len(self.history)) #DBG
		hmaxh = 0
		for i in range(24):
			self["hprogress%d" % i] = ProgressBar()
			try:
				self["hisval%d" % i] = Label(self.history[i])
				self["histimeval%d" % i] = Label(self.historytime[i])
			except IndexError:
				self["hisval%d" % i] = Label('')
				self["histimeval%d" % i] = Label('')
			self.history[i] = int(self.history[i])
			if self.history[i] > hmaxh:
				hmaxh = self.history[i]
		if hmaxh < 25:
			self.hbase = 25
		elif hmaxh < 50:
			self.hbase = 50
		elif hmaxh < 75:
			self.hbase = 75
		elif hmaxh < 100:
			self.hbase = 100
		elif hmaxh < 125:
			self.hbase = 125
		elif hmaxh < 150:
			self.hbase = 150
		elif hmaxh < 175:
			self.hbase = 175
		else:
			self.hbase = 200
		self['hlmin'] = StaticText(_('0'))
		self['hlmax'] = StaticText(str(int(self.hbase)))

		if len(self.temperature) < 24:
			for x in range(24 - len(self.temperature)):
				self.temperature.append('0')
		print_dbg('--- Histogram-temperature --->', self.temperature) #DBG
		print_dbg('--- Histogram-temperature-len --->', len(self.temperature)) #DBG
		tmaxh = 0
		tminh = 0
		for i in range(24):
			self["tposprogress%d" % i] = ProgressBar()
			self["tnegprogress%d" % i] = ProgressBar()
			try:
				self["tempval%d" % i] = Label(self.temperature[i])
				self["temptimeval%d" % i] = Label(self.temptime[i])
			except IndexError:
				self["tempval%d" % i] = Label('')
				self["temptimeval%d" % i] = Label('')
			self.temperature[i] = int(self.temperature[i])
			if self.temperature[i] <= tminh:
				tminh = self.temperature[i]
			if self.temperature[i] >= tmaxh:
				tmaxh = self.temperature[i]
		if tminh > -5 and tminh <= 0:
			self.tnbase = -5
		elif tminh > -10:
			self.tnbase = -10
		elif tminh > -15:
			self.tnbase = -15
		elif tminh > -20:
			self.tnbase = -20
		elif tminh > -30:
			self.tnbase = -30
		else:
			self.tnbase = -40
		if tmaxh >=0 and tmaxh < 5:
			self.tbase = 5
		elif tmaxh < 10:
			self.tbase = 10
		elif tmaxh < 15:
			self.tbase = 15
		elif tmaxh < 20:
			self.tbase = 20
		elif tmaxh < 30:
			self.tbase = 30
		elif tmaxh < 40:
			self.tbase = 40
		else:
			self.tbase = 50

		print_dbg('--- Histogram-temperature-tbase --->', str(self.tbase)) #DBG
		print_dbg('--- Histogram-temperature-tnbase --->', str(self.tnbase)) #DBG
		self['tlmax'] = StaticText(str(int(self.tbase)))
		self['tl0'] = StaticText(_('0'))
		self['tlmin'] = StaticText(str(int(self.tnbase)))
		
		if len(self.forecast) < 24:
			for x in range(24 - len(self.forecast)):
				 self.forecast.append('0')
		print_dbg('--- Histogram-forecast --->', self.forecast) #DBG
		print_dbg('--- Histogram-forecast-len --->', len(self.forecast)) #DBG
		fmaxh = 0
		for i in range(24):
			self["fprogress%d" % i] = ProgressBar()
			try:
				self["forval%d" % i] = Label(self.forecast[i])
				self["fortimeval%d" % i] = Label(self.historytime[i])
			except IndexError:
				self["forval%d" % i] = Label('')
				self["fortimeval%d" % i] = Label('')
			self.forecast[i] = int(self.forecast[i])
			if self.forecast[i] > fmaxh:
				fmaxh = self.forecast[i]
		if fmaxh < 25:
			self.fbase = 25
		elif fmaxh < 50:
			self.fbase = 50
		elif fmaxh < 75:
			self.fbase = 75
		elif fmaxh < 100:
			self.fbase = 100
		elif fmaxh < 125:
			self.fbase = 125
		elif fmaxh < 150:
			self.fbase = 150
		elif fmaxh < 175:
			self.fbase = 175
		else:
			self.fbase = 200
		self['flmin'] = StaticText(_('0'))
		self['flmax'] = StaticText(str(int(self.fbase)))

		print_dbg('--- Histogram-pressure --->', len(self.pressure)) #DBG

		if len(self.pressure) < 12:
			for x in range(12 - len(self.pressure)):
				 self.pressure.append('0')
		print_dbg('--- Histogram-pressure --->', self.pressure) #DBG
		print_dbg('--- Histogram-pressure-len --->', len(self.pressure)) #DBG
		pmaxh = 0
		for i in range(12):
			self["pprogress%d" % i] = ProgressBar()
			try:
				self["preval%d" % i] = Label(self.pressure[i])
				self["pretimeval%d" % i] = Label(self.pretime[i])
			except IndexError:
				self["preval%d" % i] = Label('')
				self["pretimeval%d" % i] = Label('')
			self.pressure[i] = int(self.pressure[i]) - 950
			if self.pressure[i] > pmaxh:
				pmaxh = self.pressure[i]
		if pmaxh < 10:
			self.pbase = 10
		elif pmaxh < 20:
			self.pbase = 20
		elif pmaxh < 30:
			self.pbase = 30
		elif pmaxh < 40:
			self.pbase = 40
		elif pmaxh < 50:
			self.pbase = 50
		elif pmaxh < 60:
			self.pbase = 60
		elif pmaxh < 70:
			self.pbase = 70
		elif pmaxh < 80:
			self.pbase = 80
		elif pmaxh < 90:
			self.pbase = 90
		else:
			self.pbase = 100
		self['plmin'] = StaticText(_('950'))
		self['plmax'] = StaticText(str(int(self.pbase + 950)))

		self.onExecBegin.append(self.setHistoryProgress)
		self.onExecBegin.append(self.setForecastProgress)
		self.onExecBegin.append(self.setHistTempProgress)
		self.onExecBegin.append(self.setHistPresProgress)
		self.onLayoutFinish.append(self.onLayoutFinished)

	def onLayoutFinished(self):
		if config.plugins.airly.background.value == '1':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back1.png')
		elif config.plugins.airly.background.value == '2':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back2.png')
		elif config.plugins.airly.background.value == '3':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back3.png')
		elif config.plugins.airly.background.value == '4':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back4.png')
		elif config.plugins.airly.background.value == '5':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back5.png')
		elif config.plugins.airly.background.value == '6':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back6.png')
		self.loadPNG('infoback', PLUGIN_PATH + '/gfx/infoback.png')
		self.loadPNG('header_l', PLUGIN_PATH + '/gfx/header_l.png')
		self.loadPNG('footer_l', PLUGIN_PATH + '/gfx/footer_l.png')
		self.loadPNG('alogo', PLUGIN_PATH + '/gfx/alogo.png')
		self.loadPNG('header_r', PLUGIN_PATH + '/gfx/header_r.png')
		self.loadPNG('footer_r', PLUGIN_PATH + '/gfx/footer_r.png')
		self.loadPNG('redpng', PLUGIN_PATH + '/gfx/buttons/red.png')
		self.setTitle(self.title)
		return
		
	def loadPNG(self, object, png):
		if os.path.exists(png):
			self.picload = ePicLoad()
			self[object].instance.setPixmap(gPixmapPtr())
			scale = AVSwitch().getFramebufferScale()
			size = self[object].instance.size()
			self.picload.setPara((size.width(), size.height(), scale[0], scale[0], False, 1, "#FF000000"))
			if self.picload.startDecode(png, 0, 0, False) == 0:
				ptr = self.picload.getData()
				if ptr != None:
					self[object].instance.setPixmap(ptr)
					self[object].show()
			del self.picload

	def setHistoryProgress(self):
		for i in range(24):
			hval = int((100*self.history[i])/self.hbase)
			self["hprogress%d" % i].setValue(hval)
			try:
				self["hprogress%d" % i].instance.setForegroundColor(parseColor(self.hcol[i]))
			except:
				pass
			
	def setForecastProgress(self):
		for i in range(24):
			fval = int((100*self.forecast[i])/self.fbase)
			self["fprogress%d" % i].setValue(fval)
			try:
				self["fprogress%d" % i].instance.setForegroundColor(parseColor(self.fcol[i]))
			except:
				pass

	def setHistTempProgress(self):
		for i in range(24):
			tposval = int((100*self.temperature[i])/self.tbase)
			tnegval = int((100*self.temperature[i])/self.tnbase)
			self["tposprogress%d" % i].setValue(tposval)
			self["tnegprogress%d" % i].setValue(tnegval)
			try:
				self["tposprogress%d" % i].instance.setForegroundColor(parseColor(self.tcol[i]))
				self["tnegprogress%d" % i].instance.setForegroundColor(parseColor(self.tcol[i]))
			except:
				pass
			
	def setHistPresProgress(self):
		for i in range(12):
			pval = int((100*self.pressure[i])/self.pbase)
			self["pprogress%d" % i].setValue(pval)
		
	def exit(self):
		print_dbg('-- AirlyHistogram --->', 'Exit') #DBG
		if self.hideflag == False:
			self.hideflag = True
			writeAlpha('%i' % config.av.osd_alpha.value)
		self.close()
		
	def hideScreen(self):
		self.hideflag = _hideScreen(self.hideflag)
		
class DownloadUpdate(Screen):
	skin = '\n\t<screen position="center,center" size="650,168" title="Aktualizuję plugin Airly..." >\n\t\t<ePixmap position="10,10" size="630,28" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/Airly/gfx/ulogo.png" alphatest="blend" zPosition="1" />\n\t\t<widget name="name" position="10,48" size="630,50" font="Regular;20" halign="center" valign="center" transparent="1" zPosition="1" />\n\t\t<widget name="size" position="10,98" size="630,25" font="Regular;20" halign="center" transparent="1" zPosition="1" />\n\t\t<widget name="slider" position="10,128" size="630,30" transparent="0" zPosition="2" />\n\t</screen>'
	skinFHD = '\n\t<screen position="center,center" size="975,252" title="Aktualizuję plugin Airly..." >\n\t\t<ePixmap position="15,10" size="945,42" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/Airly/gfx/ulogo_fhd.png" alphatest="blend" zPosition="1" />\n\t\t<widget name="name" position="15,62" size="945,75" font="Regular;30" halign="center" valign="center" transparent="1" zPosition="1" />\n\t\t<widget name="size" position="15,140" size="945,36" font="Regular;30" halign="center" transparent="1" zPosition="1" />\n\t\t<widget name="slider" position="10,180" size="945,45" transparent="0" zPosition="2" />\n\t</screen>'

	def __init__(self, session, url, file, name):
		display_width = getDesktop(0).size().width()
		if display_width == 1920:
			self.skin = DownloadUpdate.skinFHD
		else:
			self.skin = DownloadUpdate.skin
		print_dbg('++ DownloadUpdate --->', 'Started') #DBG
		Screen.__init__(self, session)
		self.url = url
		self.file = file
		self.name = name
		self.hideflag = True
		self.install = False
		self.filesize = 0
		self.localsize = 0
		self.progress = 0
		self.slider = Slider(0, 100)
		self['name'] = Label(_('Downloading: %s') % self.file)
		self['size'] = Label('')
		self['slider'] = self.slider
		self['actions'] = ActionMap(['OkCancelActions', 'ColorActions'], {
		 'cancel': self.exit}, -1)
		self.statusTimer = eTimer()
		self.statusTimer.callback.append(self.UpdateStatus)
		self.statusTimer.start(500, True)
		self.updateTimer = eTimer()
		self.updateTimer.callback.append(self.refresh)
		self.update_interval = 3000
		self.onLayoutFinish.append(self.onLayoutFinished)

	def onLayoutFinished(self):
		print_dbg('++ DownloadUpdate --->', 'Started') #DBG
		self.getFileSize()
		downloadPage(self.url, self.file).addCallback(self.installPlugin)

	def installPlugin(self, string):
		self.install = True
		self.container = eConsoleAppContainer()
		self.container.appClosed.append(self.finished)
		self.container.dataAvail.append(self.dataAvail)
		self.container.execute('opkg install --force-overwrite --force-reinstall %s' % self.file)

	def getFileSize(self):
		header = {'User-Agent': 'Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.6) Gecko/20027 Firefox/3.6.6',
		 'Accept-Charset': 'ISO-8859-1,utf-8;q=0.7,*;q=0.7',
		 'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
		 'Accept-Language': 'en-us,en;q=0.5'}
		request = Request(self.url, None, header)
		try:
			filesize = urlopen(request, timeout=10).info().get('Content-Length')
			filesize = float(filesize)
			self.filesize = filesize
		except URLError:
			pass
		return

	def UpdateStatus(self):
		if fileExists(self.file):
			localsize = path.getsize(self.file)
			self.localsize = localsize
		else:
			self.localsize = 0
		if self.filesize > 0:
			self.progress = self.localsize / self.filesize * 100
		if int(self.progress) > 1:
			self['slider'].setValue(int(self.progress))
			self['size'].setText('%s KB of %s KB' % (int(self.localsize) / 1024, int(self.filesize) / 1024))
		elif self.localsize > 0 and self.filesize == 0:
			self['slider'].setValue(0)
			self['size'].setText('%s KB of ??? KB' % (int(self.localsize) / 1024))
		elif self.filesize > 0 and self.localsize == 0:
			self['slider'].setValue(0)
			self['size'].setText('0 KB of %s KB' % (int(self.filesize) / 1024))
		self.updateTimer.start(self.update_interval)

	def refresh(self):
		self.UpdateStatus()

	def finished(self, retval):
		if self.hideflag == False:
			self.hideflag = True
			writeAlpha('%i' % config.av.osd_alpha.value)
		self.install = False
		del self.container.appClosed[:]
		del self.container.dataAvail[:]
		del self.container
		self.statusTimer.stop()
		self.updateTimer.stop()
		if retval == 0:
			self.setTitle('Update completed!')
			text = self.name + ' ' + 'Update completed!'
			self['name'].setText(text)
			self['slider'].setValue(100)
			self.session.openWithCallback(self.restartGUI, MessageBox, _('\n%s has been successfully installed.\nRestart the GUI ?') % self.name, MessageBox.TYPE_YESNO)
		else:
			self.close()
			
	def dataAvail(self, data):
		if data is not None:
			self.session.open(MessageBox, _('\n%s Please wait...') % data, MessageBox.TYPE_INFO, close_on_any_key=True)
		return

	def restartGUI(self, answer):
		if answer is True:
			if fileExists(self.file):
				os.remove(self.file)
			try:
				self.session.open(TryQuitMainloop, 3)
			except RuntimeError:
				self.close()
		else:
			self.close()
			
	def hideScreen(self):
			self.hideflag = _hideScreen(self.hideflag)

	def exit(self):
		print_dbg('-- DownloadUpdate --->', 'Exit') #DBG
		if self.hideflag == False:
			self.hideflag = True
			writeAlpha('%i' % config.av.osd_alpha.value)
		if self.install == True:
			del self.container.appClosed[:]
			del self.container.dataAvail[:]
			del self.container
		self.setTitle('Update interrupted!')
		self['slider'].setValue(0)
		self.statusTimer.stop()
		self.updateTimer.stop()
		if fileExists(self.file):
			os.remove(self.file)
		self.close()


class MIDList(MenuList):
	def __init__(self, list, font0 = 30):
		MenuList.__init__(self, [], False, eListboxPythonMultiContent)
		GUIComponent.__init__(self)
		self.font0 = gFont("Regular",font0)
		print_dbg('++ MIDList --->', 'Started') #DBG

	def applySkin(self, desktop, parent):
		def font(value):
			self.font0 = parseFont(value, ((1,1),(1,1)))
		for (attrib, value) in list(self.skinAttributes):
			try:
				locals().get(attrib)(value)
				self.skinAttributes.remove((attrib, value))
			except:
				pass
		self.l.setFont(0, self.font0)
		return GUIComponent.applySkin(self, desktop, parent)
		
		
class AirlyIDList(Screen):
	skinFHD = """
		<screen name="AirlyIDList" position="0,0" size="1920,1080" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Lista ID">
			<widget position="0,0" size="1920,1080" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1920,1080" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="384,48" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="20,0" size="112,45" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="180,0" size="200,45" source="tlogo" render="Label" font="AP_Regular; 20" foregroundColor="#18FFFFFF" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1792,0" size="128,48" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1792,0" size="128,48" source="global.CurrentTime" render="Label" font="AP_Regular;22" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,100" size="965,100" source="faqtitle" render="Label" font="{font2};50" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="90,170" size="920,30" source="info" render="Label" font="{font2};23" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="90,210" size="920,765" name="list" font="{font2};25" foregroundColor="#FFFFFF" itemHeight="45" enableWrapAround="1" scrollbarMode="showNever" transparent="1" zPosition="5" />
			<widget position="1100,100" size="730,100" source="legtitle" render="Label" font="{font2};50" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="1100,210" size="730,765" name="label" font="AP_Val1;25" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="1100,850" size="730,60" name="pinnedinfo" font="{font2};18" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="10" />
			<widget position="1172,900" size="30,30" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1347,900" size="30,30" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1522,900" size="30,30" name="yellowpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1697,900" size="30,30" name="bluepng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1100,930" size="175,50" name="key_red" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1275,930" size="175,50" name="key_green" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1450,930" size="175,50" name="key_yellow" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1625,930" size="175,50" name="key_blue" font="AP_Regular;22" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="0,1032" size="384,48" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1536,1032" size="384,48" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
		</screen>"""
	skin = """
		<screen name="AirlyIDList" position="0,0" size="1280,720" flags="wfNoBorder" backgroundColor="#00000000" title="Airly - Lista ID">
			<widget position="0,0" size="1280,720" name="airlyback" alphatest="off" backgroundColor="#00000000" transparent="0" zPosition="-1" />
			<widget position="0,0" size="1280,720" name="infoback" alphatest="blend" transparent="1" zPosition="3" />
			<widget position="0,0" size="250,31" name="header_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="10,2" size="49,25" name="alogo" alphatest="blend" transparent="1" zPosition="2" />
			<widget position="65,0" size="160,31" source="tlogo" render="Label" font="AP_Regular; 16" foregroundColor="#1839A0DB" halign="center" valign="center" noWrap="1" transparent="1" zPosition="2" />
			<widget position="1197,0" size="83,31" name="header_r" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1197,0" size="83,31" source="global.CurrentTime" render="Label" font="AP_Regular;18" foregroundColor="#FFFFFF" halign="center" valign="center" transparent="1" zPosition="2">
				<convert type="ClockToText">Format:%H:%M</convert>
			</widget>
			<widget position="70,70" size="610,30" source="faqtitle" render="Label" font="{font2};26" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="80,110" size="590,20" source="info" render="Label" font="{font2};14" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="70,130" size="610,525" name="list" font="{font2};16" foregroundColor="#FFFFFF" itemHeight="35" enableWrapAround="1" scrollbarMode="showNever" transparent="1" zPosition="5" />
			<widget position="740,70" size="480,30" source="legtitle" render="Label" font="{font2};26" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="740,120" size="480,525" name="label" font="AP_Val1;20" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="5" />
			<widget position="740,525" size="480,60" name="pinnedinfo" font="{font2};16" foregroundColor="#FFFFFF" halign="center" transparent="1" zPosition="10" />
			<widget position="782,600" size="20,20" name="redpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="907,600" size="20,20" name="greenpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1032,600" size="20,20" name="yellowpng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="1157,600" size="20,20" name="bluepng" alphatest="blend" transparent="1" zPosition="5" />
			<widget position="730,620" size="125,40" name="key_red" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="855,620" size="125,40" name="key_green" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="980,620" size="125,40" name="key_yellow" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="1105,620" size="125,40" name="key_blue" font="AP_Regular;16" foregroundColor="#FFFFFF" transparent="1" halign="center" valign="top" zPosition="5" />
			<widget position="0,689" size="250,31" name="footer_l" alphatest="blend" transparent="1" zPosition="1" />
			<widget position="1030,689" size="250,31" name="footer_r" alphatest="blend" transparent="1" zPosition="1" />
		</screen>"""
	def __init__(self, session):
		writeAlpha('%i' % config.plugins.airly.transparency.value)
		self.version = '1.0-r46'
		print_dbg('++ AirlyIDList --->', 'Started') #DBG
		if config.plugins.airly.font.value == 'apf1':
			font2 = 'AP_Val_desc1'
		elif config.plugins.airly.font.value == 'apf2':
			font2 = 'AP_Val_desc2'
		else:
			font2 = 'AP_Val_desc3'
		self.dict = {'font2': font2}
		self.display_width = getDesktop(0).size().width()
		if self.display_width == 1920:
			self.skin = applySkinVars(AirlyIDList.skinFHD, self.dict)
		else:
			self.skin = applySkinVars(AirlyIDList.skin, self.dict)
		self.list = []
		Screen.__init__(self, session, self.list)
		self.title = (_('Airly - ID list'))
		self.hideflag = True
		self['tlogo'] = StaticText(str(self.version))
		self['airlyback'] = Pixmap()
		self['infoback'] = Pixmap()
		self['header_l'] = Pixmap()
		self['footer_l'] = Pixmap()
		self['alogo'] = Pixmap()
		self['redpng'] = Pixmap()
		self['greenpng'] = Pixmap()
		self['yellowpng'] = Pixmap()
		self['bluepng'] = Pixmap()
		self['header_r'] = Pixmap()
		self['footer_r'] = Pixmap()
		self['faqtitle'] = StaticText(_('ID  L I S T'))
		self.udate = '08.10.2020'
		self['info'] = StaticText(_('Updated: %s') % (self.udate))
		self['legtitle'] = StaticText(_('L E G E N D'))
		self['label'] = Label(_('\n   Right : Jump forward 1 page\n   Left : Jump back 1 page\n   Bouquet- : 500 positions forward\n   Bouquet+ : 500 positions back\n   Vol- : 100 positions forward\n   Vol+ : 100 positions back'))
		self['key_red'] = Label(_('Exit'))
		if config.plugins.airly.fav1modeid.value:
			self.greenpinmode = True
			self['key_green'] = Label(_('Pin ID'))
		else:
			self.greenpinmode = False
			self['key_green'] = Label(_('Off'))
		if config.plugins.airly.fav2modeid.value:
			self.yellowpinmode = True
			self['key_yellow'] = Label(_('Pin ID'))
		else:
			self.yellowpinmode = False
			self['key_yellow'] = Label(_('Off'))
		if config.plugins.airly.hmodeid.value:
			self.bluepinmode = True
			self['key_blue'] = Label(_('Pin ID'))
		else:
			self.bluepinmode = False
			self['key_blue'] = Label(_('Off'))
		self['pinnedinfo'] = Label()
		self.list = []
		self['list'] = MIDList([])
		self['actions'] = ActionMap(['AirlyIDActions'], {
			'cancel': self.exit,
			'left': self.left,
			'right': self.right,
			'up': self.up,
			'down': self.down,
			'red': self.exit,
			'green': self.pinToGreen,
			'yellow': self.pinToYellow,
			'blue': self.pinToBlue,
			'prevBouquet': self.jump500_down,
			'nextBouquet': self.jump500_up,
			'volumeDown': self.jump100_up,
			'volumeUp': self.jump100_down,
			'hideScreen': self.hideScreen
			}, -2)
		self.updatePinnedInfoTimer = eTimer()
		self.updatePinnedInfoTimer.timeout.get().append(self.cbPinnedInfo)
		self.onLayoutFinish.append(self.onLayoutFinished)

	def onLayoutFinished(self):
		if config.plugins.airly.background.value == '1':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back1.png')
		elif config.plugins.airly.background.value == '2':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back2.png')
		elif config.plugins.airly.background.value == '3':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back3.png')
		elif config.plugins.airly.background.value == '4':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back4.png')
		elif config.plugins.airly.background.value == '5':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back5.png')
		elif config.plugins.airly.background.value == '6':
			self.loadPNG('airlyback', PLUGIN_PATH + '/gfx/airlybacks/airly_back6.png')
		self.loadPNG('infoback', PLUGIN_PATH + '/gfx/infoback.png')
		self.loadPNG('header_l', PLUGIN_PATH + '/gfx/header_l.png')
		self.loadPNG('footer_l', PLUGIN_PATH + '/gfx/footer_l.png')
		self.loadPNG('alogo', PLUGIN_PATH + '/gfx/alogo.png')
		self.loadPNG('redpng', PLUGIN_PATH + '/gfx/buttons/red.png')
		self.loadPNG('greenpng', PLUGIN_PATH + '/gfx/buttons/green.png')
		self.loadPNG('yellowpng', PLUGIN_PATH + '/gfx/buttons/yellow.png')
		self.loadPNG('bluepng', PLUGIN_PATH + '/gfx/buttons/blue.png')
		self.loadPNG('header_r', PLUGIN_PATH + '/gfx/header_r.png')
		self.loadPNG('footer_r', PLUGIN_PATH + '/gfx/footer_r.png')
		self.pickIDList()
		
	def loadPNG(self, object, png):
		if os.path.exists(png):
			self.picload = ePicLoad()
			self[object].instance.setPixmap(gPixmapPtr())
			scale = AVSwitch().getFramebufferScale()
			size = self[object].instance.size()
			self.picload.setPara((size.width(), size.height(), scale[0], scale[0], False, 1, "#FF000000"))
			if self.picload.startDecode(png, 0, 0, False) == 0:
				ptr = self.picload.getData()
				if ptr != None:
					self[object].instance.setPixmap(ptr)
					self[object].show()
			del self.picload

	def pickIDList(self):
		if config.plugins.airly.idlist.value == 'pl':
			self.runIDList(PLUGIN_PATH + '/addons/airly_installations_list.pl')
		elif config.plugins.airly.idlist.value == 'wr':
			self.runIDList(PLUGIN_PATH + '/addons/airly_installations_list.wr')
		
	def runIDList(self, file):
		self.list = []
		self.maxidx = 0
		if fileExists(file):
			f = open(file, 'r')
			for line in f:
				text = line.strip()
				self.maxidx += 1
				self.list.append(self.EntryItem((string.replace(text, "_", ""), text)))
			f.close()
		self['list'].list = self.list
		self['list'].l.setList(self.list)
		
	def EntryItem(self, entry):
		res = [entry]
		res.append(MultiContentEntryText(pos=(5, 0), size=(920, 45), font=0, text=entry[0], flags=RT_VALIGN_CENTER))
		return res
		
	def cbPinnedInfo(self):
		self.updatePinnedInfoTimer.stop()
		self['pinnedinfo'].setText('')
		if self.greenpinmode and IDPinnedToFav1:
			self['key_green'].setText(IDPinnedToFav1)
		if self.yellowpinmode and IDPinnedToFav2:
			self['key_yellow'].setText(IDPinnedToFav2)
		if self.bluepinmode and IDPinnedToHome:
			self['key_blue'].setText(IDPinnedToHome)
		self.onLayoutFinished()

	def pinToGreen(self):
		global IDPinnedToFav1
		IDPinnedToFav1 = re.search('ID:(.+?) \|', self['list'].l.getCurrentSelection()[0][1]).group(1)
		print_dbg('--- AirlyIDList-pinToGreen --->', IDPinnedToFav1) #DBG
		if self.greenpinmode:
			txt = (_('ID "%s" is now temporary stored to Favourite 1 (Green).') % IDPinnedToFav1)
			self['pinnedinfo'].setText(txt)
			self['key_green'].setText('')
			self.updatePinnedInfoTimer.start(2000)
		else:
			txt = _('Unable to Pin! ID Mode of Favourite 1 is turned off.')
			self['pinnedinfo'].setText(txt)
			self.updatePinnedInfoTimer.start(2000)

	def pinToYellow(self):
		global IDPinnedToFav2
		IDPinnedToFav2 = re.search('ID:(.+?) \|', self['list'].l.getCurrentSelection()[0][1]).group(1)
		print_dbg('--- AirlyIDList-pinToYellow --->', IDPinnedToFav2) #DBG
		if self.yellowpinmode:
			txt = (_('ID "%s" is now temporary stored to Favourite 2 (Yellow).') % IDPinnedToFav2)
			self['pinnedinfo'].setText(txt)
			self['key_yellow'].setText('')
			self.updatePinnedInfoTimer.start(2000)
		else:
			txt = _('Unable to Pin! ID Mode of Favourite 2 is turned off.')
			self['pinnedinfo'].setText(txt)
			self.updatePinnedInfoTimer.start(2000)

	def pinToBlue(self):
		global IDPinnedToHome
		IDPinnedToHome = re.search('ID:(.+?) \|', self['list'].l.getCurrentSelection()[0][1]).group(1)
		print_dbg('--- AirlyIDList-pinToBlue --->', IDPinnedToHome) #DBG
		if self.bluepinmode:
			txt = (_('ID "%s" is now temporary stored to Home (Blue).') % IDPinnedToHome)
			self['pinnedinfo'].setText(txt)
			self['key_blue'].setText('')
			self.updatePinnedInfoTimer.start(2000)
		else:
			txt = _('Unable to Pin! ID Mode of Home is turned off.')
			self['pinnedinfo'].setText(txt)
			self.updatePinnedInfoTimer.start(2000)

	def jump500_up(self):
		cur = self['list'].l.getCurrentSelectionIndex()
		if (cur + 500) <= self.maxidx:
			self['list'].instance.moveSelectionTo(cur + 500)
		else:
			self['list'].instance.moveSelectionTo(self.maxidx -1)

	def jump500_down(self):
		cur = self['list'].l.getCurrentSelectionIndex()
		if (cur - 500) >= 0:
			self['list'].instance.moveSelectionTo(cur - 500)
		else:
			self['list'].instance.moveSelectionTo(0)

	def jump100_up(self):
		cur = self['list'].l.getCurrentSelectionIndex()
		if (cur + 100) <= self.maxidx:
			self['list'].instance.moveSelectionTo(cur + 100)
		else:
			self['list'].instance.moveSelectionTo(self.maxidx -1)

	def jump100_down(self):
		cur = self['list'].l.getCurrentSelectionIndex()
		if (cur - 100) >= 0:
			self['list'].instance.moveSelectionTo(cur - 100)
		else:
			self['list'].instance.moveSelectionTo(0)

	def up(self):
		self['list'].up()

	def down(self):
		self['list'].down()

	def left(self):
		self['list'].pageUp()

	def right(self):
		self['list'].pageDown()

	def exit(self):
		print_dbg('-- AirlyIDList --->', 'Exit') #DBG
		if self.hideflag == False:
			self.hideflag = True
			writeAlpha('%i' % config.av.osd_alpha.value)
		else:
			self.close()
		
	def hideScreen(self):
		self.hideflag = _hideScreen(self.hideflag)
	 
		
class AirlyLCD(Screen):
	skin = LoadSkin('AirlyLCD')
	
	def __init__(self, session, parent):
		Screen.__init__(self, session, parent)
		
		self.version = '1.0-r46'
		self["title"] = Label("Airly")
		self["version"] = Label(self.version)

	def setTitle(self, title):
		self["Title"].setText(title)
		
def main(session, **kwargs):
	session.open(AirlyPreview)

def getAirlyData():
	print_dbg('++ Scheduler --->', 'Started') #DBG
	eConsoleAppContainer().execute('/usr/lib/enigma2/python/Plugins/Extensions/Airly/addons/scheduler.sh')
	if config.plugins.airly.scheduler.value:
		print_dbg('--- Scheduler --->', ('Task completed, next run in %s minutes' % config.plugins.airly.schedulerfrequency.value)) #DBG
		global DataRefreshTimer
		DataRefreshTimer.start(int(config.plugins.airly.schedulerfrequency.value) * 60 * 1000,True)

def sessionstart(reason, session = None):
	if config.plugins.airly.scheduler.value:
		global DataRefreshTimer
		DataRefreshTimer = eTimer()
		DataRefreshTimer.callback.append(getAirlyData)
		DataRefreshTimer.start(10000,True)

def Plugins(path, **kwargs):
	pluginname = 'Airly'
	plugindesc = (_('Quality status and air pollution level'))
	return [PluginDescriptor(name=pluginname, description=plugindesc, where=[PluginDescriptor.WHERE_PLUGINMENU],
	icon='plugin.png', fnc=main), PluginDescriptor(name="pluginname", where = PluginDescriptor.WHERE_SESSIONSTART, fnc = sessionstart, needsRestart = False, weight = -1)]
